#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17]*x[0] - y[47] + u[15] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[39];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[43];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[40];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[44];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[41];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[45];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[42];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[46];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[33];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[34];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[35];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[36];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[37];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[38];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[36] + y[16]*y[33] + 1.0*y[22]*y[37] + y[17]*y[34] + 1.0*y[23]*y[38] + 1.0*y[23]*u[1] + y[18]*y[35] + y[18]*u[0] - y[26];
out[27] = -1.0*y[1]*y[30] - y[0]*y[27] + u[2] + (1.0/3.0)*u[5];
out[28] = -1.0*y[3]*y[31] - y[2]*y[28] + u[3] + (1.0/3.0)*u[5];
out[29] = -1.0*y[5]*y[32] - y[4]*y[29] + u[4] + (1.0/3.0)*u[5];
out[30] = -1.0*y[1]*y[27] + 1.0*y[0]*y[30] + u[6] + (1.0/3.0)*u[9];
out[31] = -1.0*y[3]*y[28] + 1.0*y[2]*y[31] + u[7] + (1.0/3.0)*u[9];
out[32] = -1.0*y[5]*y[29] + 1.0*y[4]*y[32] + u[8] + (1.0/3.0)*u[9];
out[33] = -p[1]*y[27] - y[0] + 1.0*p[0]*y[30] + y[33];
out[34] = -p[1]*y[28] - y[2] + 1.0*p[0]*y[31] + y[34];
out[35] = -p[1]*y[29] - y[4] + 1.0*p[0]*y[32] + y[35];
out[36] = -1.0*p[1]*y[30] - 1.0*y[1] - p[0]*y[27] + 1.0*y[36];
out[37] = -1.0*p[1]*y[31] - 1.0*y[3] - p[0]*y[28] + 1.0*y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[5] - p[0]*y[29] + 1.0*y[38];
out[39] = -p[10]*y[39] - y[8] + 1.0*p[9]*y[43] + u[10]*cos(u[14]);
out[40] = -p[10]*y[40] - y[10] + 1.0*p[9]*y[44] + u[11]*cos(u[14] - 2.0943951023931953);
out[41] = -p[10]*y[41] - y[12] + 1.0*p[9]*y[45] + u[12]*cos(u[14] - 4.1887902047863905);
out[42] = -p[12]*y[42] - y[14] + 1.0*p[11]*y[46];
out[43] = -1.0*p[10]*y[43] - 1.0*y[9] - 1.0*p[9]*y[39] + 1.0*u[10]*sin(u[14]);
out[44] = -1.0*p[10]*y[44] - 1.0*y[11] - 1.0*p[9]*y[40] + 1.0*u[11]*sin(u[14] - 2.0943951023931953);
out[45] = -1.0*p[10]*y[45] - 1.0*y[13] - 1.0*p[9]*y[41] + 1.0*u[12]*sin(u[14] - 4.1887902047863905);
out[46] = -1.0*p[12]*y[46] - 1.0*y[15] - 1.0*p[11]*y[42];
out[47] = 1.0 - y[47];
out[48] = p[16]*x[0] + p[15]*(1 - y[47]) - y[48];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17]*x[0] - y[47] + u[15] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[39];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[43];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[40];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[44];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[41];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[45];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[42];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[46];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[33];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[34];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[35];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[36];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[37];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[38];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[36] + y[16]*y[33] + 1.0*y[22]*y[37] + y[17]*y[34] + 1.0*y[23]*y[38] + 1.0*y[23]*u[1] + y[18]*y[35] + y[18]*u[0] - y[26];
out[27] = -1.0*y[1]*y[30] - y[0]*y[27] + u[2] + (1.0/3.0)*u[5];
out[28] = -1.0*y[3]*y[31] - y[2]*y[28] + u[3] + (1.0/3.0)*u[5];
out[29] = -1.0*y[5]*y[32] - y[4]*y[29] + u[4] + (1.0/3.0)*u[5];
out[30] = -1.0*y[1]*y[27] + 1.0*y[0]*y[30] + u[6] + (1.0/3.0)*u[9];
out[31] = -1.0*y[3]*y[28] + 1.0*y[2]*y[31] + u[7] + (1.0/3.0)*u[9];
out[32] = -1.0*y[5]*y[29] + 1.0*y[4]*y[32] + u[8] + (1.0/3.0)*u[9];
out[33] = -p[1]*y[27] - y[0] + 1.0*p[0]*y[30] + y[33];
out[34] = -p[1]*y[28] - y[2] + 1.0*p[0]*y[31] + y[34];
out[35] = -p[1]*y[29] - y[4] + 1.0*p[0]*y[32] + y[35];
out[36] = -1.0*p[1]*y[30] - 1.0*y[1] - p[0]*y[27] + 1.0*y[36];
out[37] = -1.0*p[1]*y[31] - 1.0*y[3] - p[0]*y[28] + 1.0*y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[5] - p[0]*y[29] + 1.0*y[38];
out[39] = -p[10]*y[39] - y[8] + 1.0*p[9]*y[43] + u[10]*cos(u[14]);
out[40] = -p[10]*y[40] - y[10] + 1.0*p[9]*y[44] + u[11]*cos(u[14] - 2.0943951023931953);
out[41] = -p[10]*y[41] - y[12] + 1.0*p[9]*y[45] + u[12]*cos(u[14] - 4.1887902047863905);
out[42] = -p[12]*y[42] - y[14] + 1.0*p[11]*y[46];
out[43] = -1.0*p[10]*y[43] - 1.0*y[9] - 1.0*p[9]*y[39] + 1.0*u[10]*sin(u[14]);
out[44] = -1.0*p[10]*y[44] - 1.0*y[11] - 1.0*p[9]*y[40] + 1.0*u[11]*sin(u[14] - 2.0943951023931953);
out[45] = -1.0*p[10]*y[45] - 1.0*y[13] - 1.0*p[9]*y[41] + 1.0*u[12]*sin(u[14] - 4.1887902047863905);
out[46] = -1.0*p[12]*y[46] - 1.0*y[15] - 1.0*p[11]*y[42];
out[47] = 1.0 - y[47];
out[48] = p[16]*x[0] + p[15]*(1 - y[47]) - y[48];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14];
out[8] = sqrt(1.0*pow(y[21], 2) + pow(y[16], 2));
out[9] = sqrt(1.0*pow(y[22], 2) + pow(y[17], 2));
out[10] = sqrt(1.0*pow(y[23], 2) + pow(y[18], 2));
out[11] = sqrt(1.0*pow(y[24], 2) + pow(y[19], 2));
out[12] = 1.0*y[1]*y[21] + y[0]*y[16];
out[13] = 1.0*y[1]*y[16] - 1.0*y[0]*y[21];
out[14] = 1.0*y[3]*y[22] + y[2]*y[17];
out[15] = 1.0*y[3]*y[17] - 1.0*y[2]*y[22];
out[16] = 1.0*y[5]*y[23] + y[4]*y[18];
out[17] = 1.0*y[5]*y[18] - 1.0*y[4]*y[23];
out[18] = u[5];
out[19] = sqrt(1.0*pow(y[43], 2) + pow(y[39], 2));
out[20] = sqrt(1.0*pow(y[44], 2) + pow(y[40], 2));
out[21] = sqrt(1.0*pow(y[45], 2) + pow(y[41], 2));
out[22] = sqrt(1.0*pow(y[46], 2) + pow(y[42], 2));
out[23] = 1.0*y[9]*y[43] + y[8]*y[39] + 1.0*y[11]*y[44] + y[10]*y[40] + 1.0*y[13]*y[45] + y[12]*y[41];
out[24] = 1.0*y[9]*y[39] - 1.0*y[8]*y[43] + 1.0*y[11]*y[40] - 1.0*y[10]*y[44] + 1.0*y[13]*y[41] - 1.0*y[12]*y[45];
out[25] = x[0];
out[26] = u[15];

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1367] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[1368] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[1369] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[1370] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1372] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[1373] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[1374] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[1375] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1384] = y[16];
out[1385] = y[17];
out[1386] = y[18];
out[1387] = 1.0*y[21];
out[1388] = 1.0*y[22];
out[1389] = 1.0*y[23];
out[1401] = -y[27];
out[1402] = -1.0*y[30];
out[1428] = -y[0];
out[1431] = -1.0*y[1];
out[1453] = -y[28];
out[1454] = -1.0*y[31];
out[1479] = -y[2];
out[1482] = -1.0*y[3];
out[1505] = -y[29];
out[1506] = -1.0*y[32];
out[1530] = -y[4];
out[1533] = -1.0*y[5];
out[1551] = 1.0*y[30];
out[1552] = -1.0*y[27];
out[1578] = -1.0*y[1];
out[1581] = 1.0*y[0];
out[1603] = 1.0*y[31];
out[1604] = -1.0*y[28];
out[1629] = -1.0*y[3];
out[1632] = 1.0*y[2];
out[1655] = 1.0*y[32];
out[1656] = -1.0*y[29];
out[1680] = -1.0*y[5];
out[1683] = 1.0*y[4];

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[867] = -p[1];
out[872] = 1.0*p[0];
out[918] = -p[1];
out[923] = 1.0*p[0];
out[969] = -p[1];
out[974] = 1.0*p[0];
out[1020] = -p[3];
out[1025] = 1.0*p[2];
out[1071] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1076] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1117] = -1.0*p[0];
out[1122] = -1.0*p[1];
out[1168] = -1.0*p[0];
out[1173] = -1.0*p[1];
out[1219] = -1.0*p[0];
out[1224] = -1.0*p[1];
out[1270] = -1.0*p[2];
out[1275] = -1.0*p[3];
out[1321] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1326] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1728] = -p[1];
out[1731] = 1.0*p[0];
out[1779] = -p[1];
out[1782] = 1.0*p[0];
out[1830] = -p[1];
out[1833] = 1.0*p[0];
out[1878] = -p[0];
out[1881] = -1.0*p[1];
out[1929] = -p[0];
out[1932] = -1.0*p[1];
out[1980] = -p[0];
out[1983] = -1.0*p[1];
out[2040] = -p[10];
out[2044] = 1.0*p[9];
out[2091] = -p[10];
out[2095] = 1.0*p[9];
out[2142] = -p[10];
out[2146] = 1.0*p[9];
out[2193] = -p[12];
out[2197] = 1.0*p[11];
out[2240] = -1.0*p[9];
out[2244] = -1.0*p[10];
out[2291] = -1.0*p[9];
out[2295] = -1.0*p[10];
out[2342] = -1.0*p[9];
out[2346] = -1.0*p[10];
out[2393] = -1.0*p[11];
out[2397] = -1.0*p[12];
out[2450] = p[16];
out[2498] = -p[15];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[48] = -1.0;
out[51] = 184.75059629806526;
out[52] = 94.615102344455664;
out[53] = -69.368640085185305;
out[54] = -17.974903844364835;
out[55] = -43.675799641021079;
out[56] = -40.748687841669557;
out[57] = -69.368640085185291;
out[58] = -17.974903844364821;
out[59] = -184.75059629806526;
out[60] = -94.615102344455664;
out[61] = 69.368640085185305;
out[62] = 17.974903844364835;
out[63] = 43.675799641021079;
out[64] = 40.748687841669557;
out[65] = 69.368640085185291;
out[66] = 17.974903844364821;
out[67] = -1.0;
out[101] = -94.615102344455664;
out[102] = 184.75059629806526;
out[103] = 17.974903844364835;
out[104] = -69.368640085185305;
out[105] = 40.748687841669557;
out[106] = -43.675799641021079;
out[107] = 17.974903844364821;
out[108] = -69.368640085185291;
out[109] = 94.615102344455664;
out[110] = -184.75059629806526;
out[111] = -17.974903844364835;
out[112] = 69.368640085185305;
out[113] = -40.748687841669557;
out[114] = 43.675799641021079;
out[115] = -17.974903844364821;
out[116] = 69.368640085185291;
out[122] = -1.0;
out[151] = -69.368640085185291;
out[152] = -17.974903844364825;
out[153] = 184.7505962980652;
out[154] = 94.615102344455636;
out[155] = -69.368640085185319;
out[156] = -17.97490384436481;
out[157] = -43.675799641021079;
out[158] = -40.748687841669565;
out[159] = 69.368640085185291;
out[160] = 17.974903844364825;
out[161] = -184.7505962980652;
out[162] = -94.615102344455636;
out[163] = 69.368640085185319;
out[164] = 17.97490384436481;
out[165] = 43.675799641021079;
out[166] = 40.748687841669565;
out[168] = -1.0;
out[201] = 17.974903844364825;
out[202] = -69.368640085185291;
out[203] = -94.615102344455636;
out[204] = 184.7505962980652;
out[205] = 17.97490384436481;
out[206] = -69.368640085185319;
out[207] = 40.748687841669565;
out[208] = -43.675799641021079;
out[209] = -17.974903844364825;
out[210] = 69.368640085185291;
out[211] = 94.615102344455636;
out[212] = -184.7505962980652;
out[213] = -17.97490384436481;
out[214] = 69.368640085185319;
out[215] = -40.748687841669565;
out[216] = 43.675799641021079;
out[223] = -1.0;
out[251] = -43.675799641021101;
out[252] = -40.748687841669579;
out[253] = -69.368640085185305;
out[254] = -17.974903844364821;
out[255] = 184.75059629806526;
out[256] = 94.61510234445565;
out[257] = -69.368640085185305;
out[258] = -17.974903844364821;
out[259] = 43.675799641021101;
out[260] = 40.748687841669579;
out[261] = 69.368640085185305;
out[262] = 17.974903844364821;
out[263] = -184.75059629806526;
out[264] = -94.61510234445565;
out[265] = 69.368640085185305;
out[266] = 17.974903844364821;
out[269] = -1.0;
out[301] = 40.748687841669579;
out[302] = -43.675799641021101;
out[303] = 17.974903844364821;
out[304] = -69.368640085185305;
out[305] = -94.61510234445565;
out[306] = 184.75059629806526;
out[307] = 17.974903844364821;
out[308] = -69.368640085185305;
out[309] = -40.748687841669579;
out[310] = 43.675799641021101;
out[311] = -17.974903844364821;
out[312] = 69.368640085185305;
out[313] = 94.61510234445565;
out[314] = -184.75059629806526;
out[315] = -17.974903844364821;
out[316] = 69.368640085185305;
out[324] = -1.0;
out[351] = -69.368640085185305;
out[352] = -17.974903844364825;
out[353] = -43.675799641021079;
out[354] = -40.74868784166955;
out[355] = -69.368640085185291;
out[356] = -17.974903844364839;
out[357] = 184.7505962980652;
out[358] = 94.61510234445565;
out[359] = 69.368640085185305;
out[360] = 17.974903844364825;
out[361] = 43.675799641021079;
out[362] = 40.74868784166955;
out[363] = 69.368640085185291;
out[364] = 17.974903844364839;
out[365] = -184.7505962980652;
out[366] = -94.61510234445565;
out[370] = -1.0;
out[401] = 17.974903844364825;
out[402] = -69.368640085185305;
out[403] = 40.74868784166955;
out[404] = -43.675799641021079;
out[405] = 17.974903844364839;
out[406] = -69.368640085185291;
out[407] = -94.61510234445565;
out[408] = 184.7505962980652;
out[409] = -17.974903844364825;
out[410] = 69.368640085185305;
out[411] = -40.74868784166955;
out[412] = 43.675799641021079;
out[413] = -17.974903844364839;
out[414] = 69.368640085185291;
out[415] = 94.61510234445565;
out[416] = -184.7505962980652;
out[425] = -1.0;
out[451] = -184.75059629806526;
out[452] = -94.615102344455664;
out[453] = 69.368640085185305;
out[454] = 17.974903844364835;
out[455] = 43.675799641021079;
out[456] = 40.748687841669557;
out[457] = 69.368640085185291;
out[458] = 17.974903844364821;
out[459] = 184.75059629806526;
out[460] = 94.615102344455664;
out[461] = -69.368640085185305;
out[462] = -17.974903844364835;
out[463] = -43.675799641021079;
out[464] = -40.748687841669557;
out[465] = -69.368640085185291;
out[466] = -17.974903844364821;
out[490] = -1.0;
out[501] = 94.615102344455664;
out[502] = -184.75059629806526;
out[503] = -17.974903844364835;
out[504] = 69.368640085185305;
out[505] = -40.748687841669557;
out[506] = 43.675799641021079;
out[507] = -17.974903844364821;
out[508] = 69.368640085185291;
out[509] = -94.615102344455664;
out[510] = 184.75059629806526;
out[511] = 17.974903844364835;
out[512] = -69.368640085185305;
out[513] = 40.748687841669557;
out[514] = -43.675799641021079;
out[515] = 17.974903844364821;
out[516] = -69.368640085185291;
out[544] = -1.0;
out[551] = 69.368640085185291;
out[552] = 17.974903844364825;
out[553] = -184.7505962980652;
out[554] = -94.615102344455636;
out[555] = 69.368640085185319;
out[556] = 17.97490384436481;
out[557] = 43.675799641021079;
out[558] = 40.748687841669565;
out[559] = -69.368640085185291;
out[560] = -17.974903844364825;
out[561] = 184.7505962980652;
out[562] = 94.615102344455636;
out[563] = -69.368640085185319;
out[564] = -17.97490384436481;
out[565] = -43.675799641021079;
out[566] = -40.748687841669565;
out[591] = -1.0;
out[601] = -17.974903844364825;
out[602] = 69.368640085185291;
out[603] = 94.615102344455636;
out[604] = -184.7505962980652;
out[605] = -17.97490384436481;
out[606] = 69.368640085185319;
out[607] = -40.748687841669565;
out[608] = 43.675799641021079;
out[609] = 17.974903844364825;
out[610] = -69.368640085185291;
out[611] = -94.615102344455636;
out[612] = 184.7505962980652;
out[613] = 17.97490384436481;
out[614] = -69.368640085185319;
out[615] = 40.748687841669565;
out[616] = -43.675799641021079;
out[645] = -1.0;
out[651] = 43.675799641021101;
out[652] = 40.748687841669579;
out[653] = 69.368640085185305;
out[654] = 17.974903844364821;
out[655] = -184.75059629806526;
out[656] = -94.61510234445565;
out[657] = 69.368640085185305;
out[658] = 17.974903844364821;
out[659] = -43.675799641021101;
out[660] = -40.748687841669579;
out[661] = -69.368640085185305;
out[662] = -17.974903844364821;
out[663] = 184.75059629806526;
out[664] = 94.61510234445565;
out[665] = -69.368640085185305;
out[666] = -17.974903844364821;
out[692] = -1.0;
out[701] = -40.748687841669579;
out[702] = 43.675799641021101;
out[703] = -17.974903844364821;
out[704] = 69.368640085185305;
out[705] = 94.61510234445565;
out[706] = -184.75059629806526;
out[707] = -17.974903844364821;
out[708] = 69.368640085185305;
out[709] = 40.748687841669579;
out[710] = -43.675799641021101;
out[711] = 17.974903844364821;
out[712] = -69.368640085185305;
out[713] = -94.61510234445565;
out[714] = 184.75059629806526;
out[715] = 17.974903844364821;
out[716] = -69.368640085185305;
out[746] = -1.0;
out[751] = 69.368640085185305;
out[752] = 17.974903844364825;
out[753] = 43.675799641021079;
out[754] = 40.74868784166955;
out[755] = 69.368640085185291;
out[756] = 17.974903844364839;
out[757] = -184.7505962980652;
out[758] = -94.61510234445565;
out[759] = -69.368640085185305;
out[760] = -17.974903844364825;
out[761] = -43.675799641021079;
out[762] = -40.74868784166955;
out[763] = -69.368640085185291;
out[764] = -17.974903844364839;
out[765] = 184.7505962980652;
out[766] = 94.61510234445565;
out[793] = -1.0;
out[801] = -17.974903844364825;
out[802] = 69.368640085185305;
out[803] = -40.74868784166955;
out[804] = 43.675799641021079;
out[805] = -17.974903844364839;
out[806] = 69.368640085185291;
out[807] = 94.61510234445565;
out[808] = -184.7505962980652;
out[809] = 17.974903844364825;
out[810] = -69.368640085185305;
out[811] = 40.74868784166955;
out[812] = -43.675799641021079;
out[813] = 17.974903844364839;
out[814] = -69.368640085185291;
out[815] = -94.61510234445565;
out[816] = 184.7505962980652;
out[847] = -1.0;
out[851] = -1.0;
out[871] = 1.0;
out[884] = 1.0;
out[903] = -1.0;
out[921] = 1.0;
out[935] = 1.0;
out[955] = -1.0;
out[971] = 1.0;
out[986] = 1.0;
out[1007] = -1.0;
out[1021] = 1.0;
out[1067] = 1.0;
out[1068] = 1.0;
out[1069] = 1.0;
out[1070] = 1.0;
out[1102] = -1.0;
out[1126] = 1.0;
out[1137] = 1.0;
out[1154] = -1.0;
out[1176] = 1.0;
out[1188] = 1.0;
out[1206] = -1.0;
out[1226] = 1.0;
out[1239] = 1.0;
out[1258] = -1.0;
out[1276] = 1.0;
out[1322] = 1.0;
out[1323] = 1.0;
out[1324] = 1.0;
out[1325] = 1.0;
out[1377] = -1.0;
out[1701] = -1.0;
out[1734] = 1.0;
out[1753] = -1.0;
out[1785] = 1.0;
out[1805] = -1.0;
out[1836] = 1.0;
out[1852] = -1.0;
out[1887] = 1.0;
out[1904] = -1.0;
out[1938] = 1.0;
out[1956] = -1.0;
out[1989] = 1.0;
out[2009] = -1.0;
out[2061] = -1.0;
out[2113] = -1.0;
out[2165] = -1.0;
out[2210] = -1.0;
out[2262] = -1.0;
out[2314] = -1.0;
out[2366] = -1.0;
out[2448] = -1.0;
out[2499] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[324] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[325] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[326] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[327] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[328] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[329] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[330] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[331] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[333] = y[16];
out[334] = y[17];
out[335] = y[18];
out[336] = 1.0*y[21];
out[337] = 1.0*y[22];
out[338] = 1.0*y[23];
out[339] = -y[27];
out[340] = -1.0*y[30];
out[341] = -y[0];
out[342] = -1.0*y[1];
out[343] = -y[28];
out[344] = -1.0*y[31];
out[345] = -y[2];
out[346] = -1.0*y[3];
out[347] = -y[29];
out[348] = -1.0*y[32];
out[349] = -y[4];
out[350] = -1.0*y[5];
out[351] = 1.0*y[30];
out[352] = -1.0*y[27];
out[353] = -1.0*y[1];
out[354] = 1.0*y[0];
out[355] = 1.0*y[31];
out[356] = -1.0*y[28];
out[357] = -1.0*y[3];
out[358] = 1.0*y[2];
out[359] = 1.0*y[32];
out[360] = -1.0*y[29];
out[361] = -1.0*y[5];
out[362] = 1.0*y[4];

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[275] = -p[1];
out[277] = 1.0*p[0];
out[280] = -p[1];
out[282] = 1.0*p[0];
out[285] = -p[1];
out[287] = 1.0*p[0];
out[290] = -p[3];
out[292] = 1.0*p[2];
out[297] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[298] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = -1.0*p[0];
out[301] = -1.0*p[1];
out[305] = -1.0*p[0];
out[306] = -1.0*p[1];
out[310] = -1.0*p[0];
out[311] = -1.0*p[1];
out[315] = -1.0*p[2];
out[316] = -1.0*p[3];
out[318] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[323] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[364] = -p[1];
out[365] = 1.0*p[0];
out[368] = -p[1];
out[369] = 1.0*p[0];
out[372] = -p[1];
out[373] = 1.0*p[0];
out[376] = -p[0];
out[377] = -1.0*p[1];
out[380] = -p[0];
out[381] = -1.0*p[1];
out[384] = -p[0];
out[385] = -1.0*p[1];
out[388] = -p[10];
out[389] = 1.0*p[9];
out[391] = -p[10];
out[392] = 1.0*p[9];
out[394] = -p[10];
out[395] = 1.0*p[9];
out[397] = -p[12];
out[398] = 1.0*p[11];
out[400] = -1.0*p[9];
out[401] = -1.0*p[10];
out[403] = -1.0*p[9];
out[404] = -1.0*p[10];
out[406] = -1.0*p[9];
out[407] = -1.0*p[10];
out[409] = -1.0*p[11];
out[410] = -1.0*p[12];
out[412] = p[16];
out[413] = -p[15];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = -1.0;
out[2] = 184.75059629806526;
out[3] = 94.615102344455664;
out[4] = -69.368640085185305;
out[5] = -17.974903844364835;
out[6] = -43.675799641021079;
out[7] = -40.748687841669557;
out[8] = -69.368640085185291;
out[9] = -17.974903844364821;
out[10] = -184.75059629806526;
out[11] = -94.615102344455664;
out[12] = 69.368640085185305;
out[13] = 17.974903844364835;
out[14] = 43.675799641021079;
out[15] = 40.748687841669557;
out[16] = 69.368640085185291;
out[17] = 17.974903844364821;
out[18] = -1.0;
out[19] = -94.615102344455664;
out[20] = 184.75059629806526;
out[21] = 17.974903844364835;
out[22] = -69.368640085185305;
out[23] = 40.748687841669557;
out[24] = -43.675799641021079;
out[25] = 17.974903844364821;
out[26] = -69.368640085185291;
out[27] = 94.615102344455664;
out[28] = -184.75059629806526;
out[29] = -17.974903844364835;
out[30] = 69.368640085185305;
out[31] = -40.748687841669557;
out[32] = 43.675799641021079;
out[33] = -17.974903844364821;
out[34] = 69.368640085185291;
out[35] = -1.0;
out[36] = -69.368640085185291;
out[37] = -17.974903844364825;
out[38] = 184.7505962980652;
out[39] = 94.615102344455636;
out[40] = -69.368640085185319;
out[41] = -17.97490384436481;
out[42] = -43.675799641021079;
out[43] = -40.748687841669565;
out[44] = 69.368640085185291;
out[45] = 17.974903844364825;
out[46] = -184.7505962980652;
out[47] = -94.615102344455636;
out[48] = 69.368640085185319;
out[49] = 17.97490384436481;
out[50] = 43.675799641021079;
out[51] = 40.748687841669565;
out[52] = -1.0;
out[53] = 17.974903844364825;
out[54] = -69.368640085185291;
out[55] = -94.615102344455636;
out[56] = 184.7505962980652;
out[57] = 17.97490384436481;
out[58] = -69.368640085185319;
out[59] = 40.748687841669565;
out[60] = -43.675799641021079;
out[61] = -17.974903844364825;
out[62] = 69.368640085185291;
out[63] = 94.615102344455636;
out[64] = -184.7505962980652;
out[65] = -17.97490384436481;
out[66] = 69.368640085185319;
out[67] = -40.748687841669565;
out[68] = 43.675799641021079;
out[69] = -1.0;
out[70] = -43.675799641021101;
out[71] = -40.748687841669579;
out[72] = -69.368640085185305;
out[73] = -17.974903844364821;
out[74] = 184.75059629806526;
out[75] = 94.61510234445565;
out[76] = -69.368640085185305;
out[77] = -17.974903844364821;
out[78] = 43.675799641021101;
out[79] = 40.748687841669579;
out[80] = 69.368640085185305;
out[81] = 17.974903844364821;
out[82] = -184.75059629806526;
out[83] = -94.61510234445565;
out[84] = 69.368640085185305;
out[85] = 17.974903844364821;
out[86] = -1.0;
out[87] = 40.748687841669579;
out[88] = -43.675799641021101;
out[89] = 17.974903844364821;
out[90] = -69.368640085185305;
out[91] = -94.61510234445565;
out[92] = 184.75059629806526;
out[93] = 17.974903844364821;
out[94] = -69.368640085185305;
out[95] = -40.748687841669579;
out[96] = 43.675799641021101;
out[97] = -17.974903844364821;
out[98] = 69.368640085185305;
out[99] = 94.61510234445565;
out[100] = -184.75059629806526;
out[101] = -17.974903844364821;
out[102] = 69.368640085185305;
out[103] = -1.0;
out[104] = -69.368640085185305;
out[105] = -17.974903844364825;
out[106] = -43.675799641021079;
out[107] = -40.74868784166955;
out[108] = -69.368640085185291;
out[109] = -17.974903844364839;
out[110] = 184.7505962980652;
out[111] = 94.61510234445565;
out[112] = 69.368640085185305;
out[113] = 17.974903844364825;
out[114] = 43.675799641021079;
out[115] = 40.74868784166955;
out[116] = 69.368640085185291;
out[117] = 17.974903844364839;
out[118] = -184.7505962980652;
out[119] = -94.61510234445565;
out[120] = -1.0;
out[121] = 17.974903844364825;
out[122] = -69.368640085185305;
out[123] = 40.74868784166955;
out[124] = -43.675799641021079;
out[125] = 17.974903844364839;
out[126] = -69.368640085185291;
out[127] = -94.61510234445565;
out[128] = 184.7505962980652;
out[129] = -17.974903844364825;
out[130] = 69.368640085185305;
out[131] = -40.74868784166955;
out[132] = 43.675799641021079;
out[133] = -17.974903844364839;
out[134] = 69.368640085185291;
out[135] = 94.61510234445565;
out[136] = -184.7505962980652;
out[137] = -1.0;
out[138] = -184.75059629806526;
out[139] = -94.615102344455664;
out[140] = 69.368640085185305;
out[141] = 17.974903844364835;
out[142] = 43.675799641021079;
out[143] = 40.748687841669557;
out[144] = 69.368640085185291;
out[145] = 17.974903844364821;
out[146] = 184.75059629806526;
out[147] = 94.615102344455664;
out[148] = -69.368640085185305;
out[149] = -17.974903844364835;
out[150] = -43.675799641021079;
out[151] = -40.748687841669557;
out[152] = -69.368640085185291;
out[153] = -17.974903844364821;
out[154] = -1.0;
out[155] = 94.615102344455664;
out[156] = -184.75059629806526;
out[157] = -17.974903844364835;
out[158] = 69.368640085185305;
out[159] = -40.748687841669557;
out[160] = 43.675799641021079;
out[161] = -17.974903844364821;
out[162] = 69.368640085185291;
out[163] = -94.615102344455664;
out[164] = 184.75059629806526;
out[165] = 17.974903844364835;
out[166] = -69.368640085185305;
out[167] = 40.748687841669557;
out[168] = -43.675799641021079;
out[169] = 17.974903844364821;
out[170] = -69.368640085185291;
out[171] = -1.0;
out[172] = 69.368640085185291;
out[173] = 17.974903844364825;
out[174] = -184.7505962980652;
out[175] = -94.615102344455636;
out[176] = 69.368640085185319;
out[177] = 17.97490384436481;
out[178] = 43.675799641021079;
out[179] = 40.748687841669565;
out[180] = -69.368640085185291;
out[181] = -17.974903844364825;
out[182] = 184.7505962980652;
out[183] = 94.615102344455636;
out[184] = -69.368640085185319;
out[185] = -17.97490384436481;
out[186] = -43.675799641021079;
out[187] = -40.748687841669565;
out[188] = -1.0;
out[189] = -17.974903844364825;
out[190] = 69.368640085185291;
out[191] = 94.615102344455636;
out[192] = -184.7505962980652;
out[193] = -17.97490384436481;
out[194] = 69.368640085185319;
out[195] = -40.748687841669565;
out[196] = 43.675799641021079;
out[197] = 17.974903844364825;
out[198] = -69.368640085185291;
out[199] = -94.615102344455636;
out[200] = 184.7505962980652;
out[201] = 17.97490384436481;
out[202] = -69.368640085185319;
out[203] = 40.748687841669565;
out[204] = -43.675799641021079;
out[205] = -1.0;
out[206] = 43.675799641021101;
out[207] = 40.748687841669579;
out[208] = 69.368640085185305;
out[209] = 17.974903844364821;
out[210] = -184.75059629806526;
out[211] = -94.61510234445565;
out[212] = 69.368640085185305;
out[213] = 17.974903844364821;
out[214] = -43.675799641021101;
out[215] = -40.748687841669579;
out[216] = -69.368640085185305;
out[217] = -17.974903844364821;
out[218] = 184.75059629806526;
out[219] = 94.61510234445565;
out[220] = -69.368640085185305;
out[221] = -17.974903844364821;
out[222] = -1.0;
out[223] = -40.748687841669579;
out[224] = 43.675799641021101;
out[225] = -17.974903844364821;
out[226] = 69.368640085185305;
out[227] = 94.61510234445565;
out[228] = -184.75059629806526;
out[229] = -17.974903844364821;
out[230] = 69.368640085185305;
out[231] = 40.748687841669579;
out[232] = -43.675799641021101;
out[233] = 17.974903844364821;
out[234] = -69.368640085185305;
out[235] = -94.61510234445565;
out[236] = 184.75059629806526;
out[237] = 17.974903844364821;
out[238] = -69.368640085185305;
out[239] = -1.0;
out[240] = 69.368640085185305;
out[241] = 17.974903844364825;
out[242] = 43.675799641021079;
out[243] = 40.74868784166955;
out[244] = 69.368640085185291;
out[245] = 17.974903844364839;
out[246] = -184.7505962980652;
out[247] = -94.61510234445565;
out[248] = -69.368640085185305;
out[249] = -17.974903844364825;
out[250] = -43.675799641021079;
out[251] = -40.74868784166955;
out[252] = -69.368640085185291;
out[253] = -17.974903844364839;
out[254] = 184.7505962980652;
out[255] = 94.61510234445565;
out[256] = -1.0;
out[257] = -17.974903844364825;
out[258] = 69.368640085185305;
out[259] = -40.74868784166955;
out[260] = 43.675799641021079;
out[261] = -17.974903844364839;
out[262] = 69.368640085185291;
out[263] = 94.61510234445565;
out[264] = -184.7505962980652;
out[265] = 17.974903844364825;
out[266] = -69.368640085185305;
out[267] = 40.74868784166955;
out[268] = -43.675799641021079;
out[269] = 17.974903844364839;
out[270] = -69.368640085185291;
out[271] = -94.61510234445565;
out[272] = 184.7505962980652;
out[273] = -1.0;
out[274] = -1.0;
out[276] = 1.0;
out[278] = 1.0;
out[279] = -1.0;
out[281] = 1.0;
out[283] = 1.0;
out[284] = -1.0;
out[286] = 1.0;
out[288] = 1.0;
out[289] = -1.0;
out[291] = 1.0;
out[293] = 1.0;
out[294] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[299] = -1.0;
out[302] = 1.0;
out[303] = 1.0;
out[304] = -1.0;
out[307] = 1.0;
out[308] = 1.0;
out[309] = -1.0;
out[312] = 1.0;
out[313] = 1.0;
out[314] = -1.0;
out[317] = 1.0;
out[319] = 1.0;
out[320] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[332] = -1.0;
out[363] = -1.0;
out[366] = 1.0;
out[367] = -1.0;
out[370] = 1.0;
out[371] = -1.0;
out[374] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = -1.0;
out[382] = 1.0;
out[383] = -1.0;
out[386] = 1.0;
out[387] = -1.0;
out[390] = -1.0;
out[393] = -1.0;
out[396] = -1.0;
out[399] = -1.0;
out[402] = -1.0;
out[405] = -1.0;
out[408] = -1.0;
out[411] = -1.0;
out[414] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1367] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[1368] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[1369] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[1370] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1372] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[1373] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[1374] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[1375] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1384] = y[16];
out[1385] = y[17];
out[1386] = y[18];
out[1387] = 1.0*y[21];
out[1388] = 1.0*y[22];
out[1389] = 1.0*y[23];
out[1401] = -y[27];
out[1402] = -1.0*y[30];
out[1428] = -y[0];
out[1431] = -1.0*y[1];
out[1453] = -y[28];
out[1454] = -1.0*y[31];
out[1479] = -y[2];
out[1482] = -1.0*y[3];
out[1505] = -y[29];
out[1506] = -1.0*y[32];
out[1530] = -y[4];
out[1533] = -1.0*y[5];
out[1551] = 1.0*y[30];
out[1552] = -1.0*y[27];
out[1578] = -1.0*y[1];
out[1581] = 1.0*y[0];
out[1603] = 1.0*y[31];
out[1604] = -1.0*y[28];
out[1629] = -1.0*y[3];
out[1632] = 1.0*y[2];
out[1655] = 1.0*y[32];
out[1656] = -1.0*y[29];
out[1680] = -1.0*y[5];
out[1683] = 1.0*y[4];

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[867] = -p[1];
out[872] = 1.0*p[0];
out[918] = -p[1];
out[923] = 1.0*p[0];
out[969] = -p[1];
out[974] = 1.0*p[0];
out[1020] = -p[3];
out[1025] = 1.0*p[2];
out[1071] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1076] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1117] = -1.0*p[0];
out[1122] = -1.0*p[1];
out[1168] = -1.0*p[0];
out[1173] = -1.0*p[1];
out[1219] = -1.0*p[0];
out[1224] = -1.0*p[1];
out[1270] = -1.0*p[2];
out[1275] = -1.0*p[3];
out[1321] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1326] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1728] = -p[1];
out[1731] = 1.0*p[0];
out[1779] = -p[1];
out[1782] = 1.0*p[0];
out[1830] = -p[1];
out[1833] = 1.0*p[0];
out[1878] = -p[0];
out[1881] = -1.0*p[1];
out[1929] = -p[0];
out[1932] = -1.0*p[1];
out[1980] = -p[0];
out[1983] = -1.0*p[1];
out[2040] = -p[10];
out[2044] = 1.0*p[9];
out[2091] = -p[10];
out[2095] = 1.0*p[9];
out[2142] = -p[10];
out[2146] = 1.0*p[9];
out[2193] = -p[12];
out[2197] = 1.0*p[11];
out[2240] = -1.0*p[9];
out[2244] = -1.0*p[10];
out[2291] = -1.0*p[9];
out[2295] = -1.0*p[10];
out[2342] = -1.0*p[9];
out[2346] = -1.0*p[10];
out[2393] = -1.0*p[11];
out[2397] = -1.0*p[12];
out[2450] = p[16];
out[2498] = -p[15];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[48] = -1.0;
out[51] = 184.75059629806526;
out[52] = 94.615102344455664;
out[53] = -69.368640085185305;
out[54] = -17.974903844364835;
out[55] = -43.675799641021079;
out[56] = -40.748687841669557;
out[57] = -69.368640085185291;
out[58] = -17.974903844364821;
out[59] = -184.75059629806526;
out[60] = -94.615102344455664;
out[61] = 69.368640085185305;
out[62] = 17.974903844364835;
out[63] = 43.675799641021079;
out[64] = 40.748687841669557;
out[65] = 69.368640085185291;
out[66] = 17.974903844364821;
out[67] = -1.0;
out[101] = -94.615102344455664;
out[102] = 184.75059629806526;
out[103] = 17.974903844364835;
out[104] = -69.368640085185305;
out[105] = 40.748687841669557;
out[106] = -43.675799641021079;
out[107] = 17.974903844364821;
out[108] = -69.368640085185291;
out[109] = 94.615102344455664;
out[110] = -184.75059629806526;
out[111] = -17.974903844364835;
out[112] = 69.368640085185305;
out[113] = -40.748687841669557;
out[114] = 43.675799641021079;
out[115] = -17.974903844364821;
out[116] = 69.368640085185291;
out[122] = -1.0;
out[151] = -69.368640085185291;
out[152] = -17.974903844364825;
out[153] = 184.7505962980652;
out[154] = 94.615102344455636;
out[155] = -69.368640085185319;
out[156] = -17.97490384436481;
out[157] = -43.675799641021079;
out[158] = -40.748687841669565;
out[159] = 69.368640085185291;
out[160] = 17.974903844364825;
out[161] = -184.7505962980652;
out[162] = -94.615102344455636;
out[163] = 69.368640085185319;
out[164] = 17.97490384436481;
out[165] = 43.675799641021079;
out[166] = 40.748687841669565;
out[168] = -1.0;
out[201] = 17.974903844364825;
out[202] = -69.368640085185291;
out[203] = -94.615102344455636;
out[204] = 184.7505962980652;
out[205] = 17.97490384436481;
out[206] = -69.368640085185319;
out[207] = 40.748687841669565;
out[208] = -43.675799641021079;
out[209] = -17.974903844364825;
out[210] = 69.368640085185291;
out[211] = 94.615102344455636;
out[212] = -184.7505962980652;
out[213] = -17.97490384436481;
out[214] = 69.368640085185319;
out[215] = -40.748687841669565;
out[216] = 43.675799641021079;
out[223] = -1.0;
out[251] = -43.675799641021101;
out[252] = -40.748687841669579;
out[253] = -69.368640085185305;
out[254] = -17.974903844364821;
out[255] = 184.75059629806526;
out[256] = 94.61510234445565;
out[257] = -69.368640085185305;
out[258] = -17.974903844364821;
out[259] = 43.675799641021101;
out[260] = 40.748687841669579;
out[261] = 69.368640085185305;
out[262] = 17.974903844364821;
out[263] = -184.75059629806526;
out[264] = -94.61510234445565;
out[265] = 69.368640085185305;
out[266] = 17.974903844364821;
out[269] = -1.0;
out[301] = 40.748687841669579;
out[302] = -43.675799641021101;
out[303] = 17.974903844364821;
out[304] = -69.368640085185305;
out[305] = -94.61510234445565;
out[306] = 184.75059629806526;
out[307] = 17.974903844364821;
out[308] = -69.368640085185305;
out[309] = -40.748687841669579;
out[310] = 43.675799641021101;
out[311] = -17.974903844364821;
out[312] = 69.368640085185305;
out[313] = 94.61510234445565;
out[314] = -184.75059629806526;
out[315] = -17.974903844364821;
out[316] = 69.368640085185305;
out[324] = -1.0;
out[351] = -69.368640085185305;
out[352] = -17.974903844364825;
out[353] = -43.675799641021079;
out[354] = -40.74868784166955;
out[355] = -69.368640085185291;
out[356] = -17.974903844364839;
out[357] = 184.7505962980652;
out[358] = 94.61510234445565;
out[359] = 69.368640085185305;
out[360] = 17.974903844364825;
out[361] = 43.675799641021079;
out[362] = 40.74868784166955;
out[363] = 69.368640085185291;
out[364] = 17.974903844364839;
out[365] = -184.7505962980652;
out[366] = -94.61510234445565;
out[370] = -1.0;
out[401] = 17.974903844364825;
out[402] = -69.368640085185305;
out[403] = 40.74868784166955;
out[404] = -43.675799641021079;
out[405] = 17.974903844364839;
out[406] = -69.368640085185291;
out[407] = -94.61510234445565;
out[408] = 184.7505962980652;
out[409] = -17.974903844364825;
out[410] = 69.368640085185305;
out[411] = -40.74868784166955;
out[412] = 43.675799641021079;
out[413] = -17.974903844364839;
out[414] = 69.368640085185291;
out[415] = 94.61510234445565;
out[416] = -184.7505962980652;
out[425] = -1.0;
out[451] = -184.75059629806526;
out[452] = -94.615102344455664;
out[453] = 69.368640085185305;
out[454] = 17.974903844364835;
out[455] = 43.675799641021079;
out[456] = 40.748687841669557;
out[457] = 69.368640085185291;
out[458] = 17.974903844364821;
out[459] = 184.75059629806526;
out[460] = 94.615102344455664;
out[461] = -69.368640085185305;
out[462] = -17.974903844364835;
out[463] = -43.675799641021079;
out[464] = -40.748687841669557;
out[465] = -69.368640085185291;
out[466] = -17.974903844364821;
out[490] = -1.0;
out[501] = 94.615102344455664;
out[502] = -184.75059629806526;
out[503] = -17.974903844364835;
out[504] = 69.368640085185305;
out[505] = -40.748687841669557;
out[506] = 43.675799641021079;
out[507] = -17.974903844364821;
out[508] = 69.368640085185291;
out[509] = -94.615102344455664;
out[510] = 184.75059629806526;
out[511] = 17.974903844364835;
out[512] = -69.368640085185305;
out[513] = 40.748687841669557;
out[514] = -43.675799641021079;
out[515] = 17.974903844364821;
out[516] = -69.368640085185291;
out[544] = -1.0;
out[551] = 69.368640085185291;
out[552] = 17.974903844364825;
out[553] = -184.7505962980652;
out[554] = -94.615102344455636;
out[555] = 69.368640085185319;
out[556] = 17.97490384436481;
out[557] = 43.675799641021079;
out[558] = 40.748687841669565;
out[559] = -69.368640085185291;
out[560] = -17.974903844364825;
out[561] = 184.7505962980652;
out[562] = 94.615102344455636;
out[563] = -69.368640085185319;
out[564] = -17.97490384436481;
out[565] = -43.675799641021079;
out[566] = -40.748687841669565;
out[591] = -1.0;
out[601] = -17.974903844364825;
out[602] = 69.368640085185291;
out[603] = 94.615102344455636;
out[604] = -184.7505962980652;
out[605] = -17.97490384436481;
out[606] = 69.368640085185319;
out[607] = -40.748687841669565;
out[608] = 43.675799641021079;
out[609] = 17.974903844364825;
out[610] = -69.368640085185291;
out[611] = -94.615102344455636;
out[612] = 184.7505962980652;
out[613] = 17.97490384436481;
out[614] = -69.368640085185319;
out[615] = 40.748687841669565;
out[616] = -43.675799641021079;
out[645] = -1.0;
out[651] = 43.675799641021101;
out[652] = 40.748687841669579;
out[653] = 69.368640085185305;
out[654] = 17.974903844364821;
out[655] = -184.75059629806526;
out[656] = -94.61510234445565;
out[657] = 69.368640085185305;
out[658] = 17.974903844364821;
out[659] = -43.675799641021101;
out[660] = -40.748687841669579;
out[661] = -69.368640085185305;
out[662] = -17.974903844364821;
out[663] = 184.75059629806526;
out[664] = 94.61510234445565;
out[665] = -69.368640085185305;
out[666] = -17.974903844364821;
out[692] = -1.0;
out[701] = -40.748687841669579;
out[702] = 43.675799641021101;
out[703] = -17.974903844364821;
out[704] = 69.368640085185305;
out[705] = 94.61510234445565;
out[706] = -184.75059629806526;
out[707] = -17.974903844364821;
out[708] = 69.368640085185305;
out[709] = 40.748687841669579;
out[710] = -43.675799641021101;
out[711] = 17.974903844364821;
out[712] = -69.368640085185305;
out[713] = -94.61510234445565;
out[714] = 184.75059629806526;
out[715] = 17.974903844364821;
out[716] = -69.368640085185305;
out[746] = -1.0;
out[751] = 69.368640085185305;
out[752] = 17.974903844364825;
out[753] = 43.675799641021079;
out[754] = 40.74868784166955;
out[755] = 69.368640085185291;
out[756] = 17.974903844364839;
out[757] = -184.7505962980652;
out[758] = -94.61510234445565;
out[759] = -69.368640085185305;
out[760] = -17.974903844364825;
out[761] = -43.675799641021079;
out[762] = -40.74868784166955;
out[763] = -69.368640085185291;
out[764] = -17.974903844364839;
out[765] = 184.7505962980652;
out[766] = 94.61510234445565;
out[793] = -1.0;
out[801] = -17.974903844364825;
out[802] = 69.368640085185305;
out[803] = -40.74868784166955;
out[804] = 43.675799641021079;
out[805] = -17.974903844364839;
out[806] = 69.368640085185291;
out[807] = 94.61510234445565;
out[808] = -184.7505962980652;
out[809] = 17.974903844364825;
out[810] = -69.368640085185305;
out[811] = 40.74868784166955;
out[812] = -43.675799641021079;
out[813] = 17.974903844364839;
out[814] = -69.368640085185291;
out[815] = -94.61510234445565;
out[816] = 184.7505962980652;
out[847] = -1.0;
out[851] = -1.0;
out[871] = 1.0;
out[884] = 1.0;
out[903] = -1.0;
out[921] = 1.0;
out[935] = 1.0;
out[955] = -1.0;
out[971] = 1.0;
out[986] = 1.0;
out[1007] = -1.0;
out[1021] = 1.0;
out[1067] = 1.0;
out[1068] = 1.0;
out[1069] = 1.0;
out[1070] = 1.0;
out[1102] = -1.0;
out[1126] = 1.0;
out[1137] = 1.0;
out[1154] = -1.0;
out[1176] = 1.0;
out[1188] = 1.0;
out[1206] = -1.0;
out[1226] = 1.0;
out[1239] = 1.0;
out[1258] = -1.0;
out[1276] = 1.0;
out[1322] = 1.0;
out[1323] = 1.0;
out[1324] = 1.0;
out[1325] = 1.0;
out[1377] = -1.0;
out[1701] = -1.0;
out[1734] = 1.0;
out[1753] = -1.0;
out[1785] = 1.0;
out[1805] = -1.0;
out[1836] = 1.0;
out[1852] = -1.0;
out[1887] = 1.0;
out[1904] = -1.0;
out[1938] = 1.0;
out[1956] = -1.0;
out[1989] = 1.0;
out[2009] = -1.0;
out[2061] = -1.0;
out[2113] = -1.0;
out[2165] = -1.0;
out[2210] = -1.0;
out[2262] = -1.0;
out[2314] = -1.0;
out[2366] = -1.0;
out[2448] = -1.0;
out[2499] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[324] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[325] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[326] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[327] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[328] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[329] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[330] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[331] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[333] = y[16];
out[334] = y[17];
out[335] = y[18];
out[336] = 1.0*y[21];
out[337] = 1.0*y[22];
out[338] = 1.0*y[23];
out[339] = -y[27];
out[340] = -1.0*y[30];
out[341] = -y[0];
out[342] = -1.0*y[1];
out[343] = -y[28];
out[344] = -1.0*y[31];
out[345] = -y[2];
out[346] = -1.0*y[3];
out[347] = -y[29];
out[348] = -1.0*y[32];
out[349] = -y[4];
out[350] = -1.0*y[5];
out[351] = 1.0*y[30];
out[352] = -1.0*y[27];
out[353] = -1.0*y[1];
out[354] = 1.0*y[0];
out[355] = 1.0*y[31];
out[356] = -1.0*y[28];
out[357] = -1.0*y[3];
out[358] = 1.0*y[2];
out[359] = 1.0*y[32];
out[360] = -1.0*y[29];
out[361] = -1.0*y[5];
out[362] = 1.0*y[4];

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[17];
out[275] = -p[1];
out[277] = 1.0*p[0];
out[280] = -p[1];
out[282] = 1.0*p[0];
out[285] = -p[1];
out[287] = 1.0*p[0];
out[290] = -p[3];
out[292] = 1.0*p[2];
out[297] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[298] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = -1.0*p[0];
out[301] = -1.0*p[1];
out[305] = -1.0*p[0];
out[306] = -1.0*p[1];
out[310] = -1.0*p[0];
out[311] = -1.0*p[1];
out[315] = -1.0*p[2];
out[316] = -1.0*p[3];
out[318] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[323] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[364] = -p[1];
out[365] = 1.0*p[0];
out[368] = -p[1];
out[369] = 1.0*p[0];
out[372] = -p[1];
out[373] = 1.0*p[0];
out[376] = -p[0];
out[377] = -1.0*p[1];
out[380] = -p[0];
out[381] = -1.0*p[1];
out[384] = -p[0];
out[385] = -1.0*p[1];
out[388] = -p[10];
out[389] = 1.0*p[9];
out[391] = -p[10];
out[392] = 1.0*p[9];
out[394] = -p[10];
out[395] = 1.0*p[9];
out[397] = -p[12];
out[398] = 1.0*p[11];
out[400] = -1.0*p[9];
out[401] = -1.0*p[10];
out[403] = -1.0*p[9];
out[404] = -1.0*p[10];
out[406] = -1.0*p[9];
out[407] = -1.0*p[10];
out[409] = -1.0*p[11];
out[410] = -1.0*p[12];
out[412] = p[16];
out[413] = -p[15];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = -1.0;
out[2] = 184.75059629806526;
out[3] = 94.615102344455664;
out[4] = -69.368640085185305;
out[5] = -17.974903844364835;
out[6] = -43.675799641021079;
out[7] = -40.748687841669557;
out[8] = -69.368640085185291;
out[9] = -17.974903844364821;
out[10] = -184.75059629806526;
out[11] = -94.615102344455664;
out[12] = 69.368640085185305;
out[13] = 17.974903844364835;
out[14] = 43.675799641021079;
out[15] = 40.748687841669557;
out[16] = 69.368640085185291;
out[17] = 17.974903844364821;
out[18] = -1.0;
out[19] = -94.615102344455664;
out[20] = 184.75059629806526;
out[21] = 17.974903844364835;
out[22] = -69.368640085185305;
out[23] = 40.748687841669557;
out[24] = -43.675799641021079;
out[25] = 17.974903844364821;
out[26] = -69.368640085185291;
out[27] = 94.615102344455664;
out[28] = -184.75059629806526;
out[29] = -17.974903844364835;
out[30] = 69.368640085185305;
out[31] = -40.748687841669557;
out[32] = 43.675799641021079;
out[33] = -17.974903844364821;
out[34] = 69.368640085185291;
out[35] = -1.0;
out[36] = -69.368640085185291;
out[37] = -17.974903844364825;
out[38] = 184.7505962980652;
out[39] = 94.615102344455636;
out[40] = -69.368640085185319;
out[41] = -17.97490384436481;
out[42] = -43.675799641021079;
out[43] = -40.748687841669565;
out[44] = 69.368640085185291;
out[45] = 17.974903844364825;
out[46] = -184.7505962980652;
out[47] = -94.615102344455636;
out[48] = 69.368640085185319;
out[49] = 17.97490384436481;
out[50] = 43.675799641021079;
out[51] = 40.748687841669565;
out[52] = -1.0;
out[53] = 17.974903844364825;
out[54] = -69.368640085185291;
out[55] = -94.615102344455636;
out[56] = 184.7505962980652;
out[57] = 17.97490384436481;
out[58] = -69.368640085185319;
out[59] = 40.748687841669565;
out[60] = -43.675799641021079;
out[61] = -17.974903844364825;
out[62] = 69.368640085185291;
out[63] = 94.615102344455636;
out[64] = -184.7505962980652;
out[65] = -17.97490384436481;
out[66] = 69.368640085185319;
out[67] = -40.748687841669565;
out[68] = 43.675799641021079;
out[69] = -1.0;
out[70] = -43.675799641021101;
out[71] = -40.748687841669579;
out[72] = -69.368640085185305;
out[73] = -17.974903844364821;
out[74] = 184.75059629806526;
out[75] = 94.61510234445565;
out[76] = -69.368640085185305;
out[77] = -17.974903844364821;
out[78] = 43.675799641021101;
out[79] = 40.748687841669579;
out[80] = 69.368640085185305;
out[81] = 17.974903844364821;
out[82] = -184.75059629806526;
out[83] = -94.61510234445565;
out[84] = 69.368640085185305;
out[85] = 17.974903844364821;
out[86] = -1.0;
out[87] = 40.748687841669579;
out[88] = -43.675799641021101;
out[89] = 17.974903844364821;
out[90] = -69.368640085185305;
out[91] = -94.61510234445565;
out[92] = 184.75059629806526;
out[93] = 17.974903844364821;
out[94] = -69.368640085185305;
out[95] = -40.748687841669579;
out[96] = 43.675799641021101;
out[97] = -17.974903844364821;
out[98] = 69.368640085185305;
out[99] = 94.61510234445565;
out[100] = -184.75059629806526;
out[101] = -17.974903844364821;
out[102] = 69.368640085185305;
out[103] = -1.0;
out[104] = -69.368640085185305;
out[105] = -17.974903844364825;
out[106] = -43.675799641021079;
out[107] = -40.74868784166955;
out[108] = -69.368640085185291;
out[109] = -17.974903844364839;
out[110] = 184.7505962980652;
out[111] = 94.61510234445565;
out[112] = 69.368640085185305;
out[113] = 17.974903844364825;
out[114] = 43.675799641021079;
out[115] = 40.74868784166955;
out[116] = 69.368640085185291;
out[117] = 17.974903844364839;
out[118] = -184.7505962980652;
out[119] = -94.61510234445565;
out[120] = -1.0;
out[121] = 17.974903844364825;
out[122] = -69.368640085185305;
out[123] = 40.74868784166955;
out[124] = -43.675799641021079;
out[125] = 17.974903844364839;
out[126] = -69.368640085185291;
out[127] = -94.61510234445565;
out[128] = 184.7505962980652;
out[129] = -17.974903844364825;
out[130] = 69.368640085185305;
out[131] = -40.74868784166955;
out[132] = 43.675799641021079;
out[133] = -17.974903844364839;
out[134] = 69.368640085185291;
out[135] = 94.61510234445565;
out[136] = -184.7505962980652;
out[137] = -1.0;
out[138] = -184.75059629806526;
out[139] = -94.615102344455664;
out[140] = 69.368640085185305;
out[141] = 17.974903844364835;
out[142] = 43.675799641021079;
out[143] = 40.748687841669557;
out[144] = 69.368640085185291;
out[145] = 17.974903844364821;
out[146] = 184.75059629806526;
out[147] = 94.615102344455664;
out[148] = -69.368640085185305;
out[149] = -17.974903844364835;
out[150] = -43.675799641021079;
out[151] = -40.748687841669557;
out[152] = -69.368640085185291;
out[153] = -17.974903844364821;
out[154] = -1.0;
out[155] = 94.615102344455664;
out[156] = -184.75059629806526;
out[157] = -17.974903844364835;
out[158] = 69.368640085185305;
out[159] = -40.748687841669557;
out[160] = 43.675799641021079;
out[161] = -17.974903844364821;
out[162] = 69.368640085185291;
out[163] = -94.615102344455664;
out[164] = 184.75059629806526;
out[165] = 17.974903844364835;
out[166] = -69.368640085185305;
out[167] = 40.748687841669557;
out[168] = -43.675799641021079;
out[169] = 17.974903844364821;
out[170] = -69.368640085185291;
out[171] = -1.0;
out[172] = 69.368640085185291;
out[173] = 17.974903844364825;
out[174] = -184.7505962980652;
out[175] = -94.615102344455636;
out[176] = 69.368640085185319;
out[177] = 17.97490384436481;
out[178] = 43.675799641021079;
out[179] = 40.748687841669565;
out[180] = -69.368640085185291;
out[181] = -17.974903844364825;
out[182] = 184.7505962980652;
out[183] = 94.615102344455636;
out[184] = -69.368640085185319;
out[185] = -17.97490384436481;
out[186] = -43.675799641021079;
out[187] = -40.748687841669565;
out[188] = -1.0;
out[189] = -17.974903844364825;
out[190] = 69.368640085185291;
out[191] = 94.615102344455636;
out[192] = -184.7505962980652;
out[193] = -17.97490384436481;
out[194] = 69.368640085185319;
out[195] = -40.748687841669565;
out[196] = 43.675799641021079;
out[197] = 17.974903844364825;
out[198] = -69.368640085185291;
out[199] = -94.615102344455636;
out[200] = 184.7505962980652;
out[201] = 17.97490384436481;
out[202] = -69.368640085185319;
out[203] = 40.748687841669565;
out[204] = -43.675799641021079;
out[205] = -1.0;
out[206] = 43.675799641021101;
out[207] = 40.748687841669579;
out[208] = 69.368640085185305;
out[209] = 17.974903844364821;
out[210] = -184.75059629806526;
out[211] = -94.61510234445565;
out[212] = 69.368640085185305;
out[213] = 17.974903844364821;
out[214] = -43.675799641021101;
out[215] = -40.748687841669579;
out[216] = -69.368640085185305;
out[217] = -17.974903844364821;
out[218] = 184.75059629806526;
out[219] = 94.61510234445565;
out[220] = -69.368640085185305;
out[221] = -17.974903844364821;
out[222] = -1.0;
out[223] = -40.748687841669579;
out[224] = 43.675799641021101;
out[225] = -17.974903844364821;
out[226] = 69.368640085185305;
out[227] = 94.61510234445565;
out[228] = -184.75059629806526;
out[229] = -17.974903844364821;
out[230] = 69.368640085185305;
out[231] = 40.748687841669579;
out[232] = -43.675799641021101;
out[233] = 17.974903844364821;
out[234] = -69.368640085185305;
out[235] = -94.61510234445565;
out[236] = 184.75059629806526;
out[237] = 17.974903844364821;
out[238] = -69.368640085185305;
out[239] = -1.0;
out[240] = 69.368640085185305;
out[241] = 17.974903844364825;
out[242] = 43.675799641021079;
out[243] = 40.74868784166955;
out[244] = 69.368640085185291;
out[245] = 17.974903844364839;
out[246] = -184.7505962980652;
out[247] = -94.61510234445565;
out[248] = -69.368640085185305;
out[249] = -17.974903844364825;
out[250] = -43.675799641021079;
out[251] = -40.74868784166955;
out[252] = -69.368640085185291;
out[253] = -17.974903844364839;
out[254] = 184.7505962980652;
out[255] = 94.61510234445565;
out[256] = -1.0;
out[257] = -17.974903844364825;
out[258] = 69.368640085185305;
out[259] = -40.74868784166955;
out[260] = 43.675799641021079;
out[261] = -17.974903844364839;
out[262] = 69.368640085185291;
out[263] = 94.61510234445565;
out[264] = -184.7505962980652;
out[265] = 17.974903844364825;
out[266] = -69.368640085185305;
out[267] = 40.74868784166955;
out[268] = -43.675799641021079;
out[269] = 17.974903844364839;
out[270] = -69.368640085185291;
out[271] = -94.61510234445565;
out[272] = 184.7505962980652;
out[273] = -1.0;
out[274] = -1.0;
out[276] = 1.0;
out[278] = 1.0;
out[279] = -1.0;
out[281] = 1.0;
out[283] = 1.0;
out[284] = -1.0;
out[286] = 1.0;
out[288] = 1.0;
out[289] = -1.0;
out[291] = 1.0;
out[293] = 1.0;
out[294] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[299] = -1.0;
out[302] = 1.0;
out[303] = 1.0;
out[304] = -1.0;
out[307] = 1.0;
out[308] = 1.0;
out[309] = -1.0;
out[312] = 1.0;
out[313] = 1.0;
out[314] = -1.0;
out[317] = 1.0;
out[319] = 1.0;
out[320] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[332] = -1.0;
out[363] = -1.0;
out[366] = 1.0;
out[367] = -1.0;
out[370] = 1.0;
out[371] = -1.0;
out[374] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = -1.0;
out[382] = 1.0;
out[383] = -1.0;
out[386] = 1.0;
out[387] = -1.0;
out[390] = -1.0;
out[393] = -1.0;
out[396] = -1.0;
out[399] = -1.0;
out[402] = -1.0;
out[405] = -1.0;
out[408] = -1.0;
out[411] = -1.0;
out[414] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1367] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[1368] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[1369] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[1370] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1372] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[1373] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[1374] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[1375] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1384] = y[16];
out[1385] = y[17];
out[1386] = y[18];
out[1387] = 1.0*y[21];
out[1388] = 1.0*y[22];
out[1389] = 1.0*y[23];
out[1401] = -y[27];
out[1402] = -1.0*y[30];
out[1428] = -y[0];
out[1431] = -1.0*y[1];
out[1453] = -y[28];
out[1454] = -1.0*y[31];
out[1479] = -y[2];
out[1482] = -1.0*y[3];
out[1505] = -y[29];
out[1506] = -1.0*y[32];
out[1530] = -y[4];
out[1533] = -1.0*y[5];
out[1551] = 1.0*y[30];
out[1552] = -1.0*y[27];
out[1578] = -1.0*y[1];
out[1581] = 1.0*y[0];
out[1603] = 1.0*y[31];
out[1604] = -1.0*y[28];
out[1629] = -1.0*y[3];
out[1632] = 1.0*y[2];
out[1655] = 1.0*y[32];
out[1656] = -1.0*y[29];
out[1680] = -1.0*y[5];
out[1683] = 1.0*y[4];

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[17] + 1.0;
out[48] = 0.5*Dt;
out[867] = -p[1];
out[872] = 1.0*p[0];
out[918] = -p[1];
out[923] = 1.0*p[0];
out[969] = -p[1];
out[974] = 1.0*p[0];
out[1020] = -p[3];
out[1025] = 1.0*p[2];
out[1071] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1076] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1117] = -1.0*p[0];
out[1122] = -1.0*p[1];
out[1168] = -1.0*p[0];
out[1173] = -1.0*p[1];
out[1219] = -1.0*p[0];
out[1224] = -1.0*p[1];
out[1270] = -1.0*p[2];
out[1275] = -1.0*p[3];
out[1321] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1326] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1728] = -p[1];
out[1731] = 1.0*p[0];
out[1779] = -p[1];
out[1782] = 1.0*p[0];
out[1830] = -p[1];
out[1833] = 1.0*p[0];
out[1878] = -p[0];
out[1881] = -1.0*p[1];
out[1929] = -p[0];
out[1932] = -1.0*p[1];
out[1980] = -p[0];
out[1983] = -1.0*p[1];
out[2040] = -p[10];
out[2044] = 1.0*p[9];
out[2091] = -p[10];
out[2095] = 1.0*p[9];
out[2142] = -p[10];
out[2146] = 1.0*p[9];
out[2193] = -p[12];
out[2197] = 1.0*p[11];
out[2240] = -1.0*p[9];
out[2244] = -1.0*p[10];
out[2291] = -1.0*p[9];
out[2295] = -1.0*p[10];
out[2342] = -1.0*p[9];
out[2346] = -1.0*p[10];
out[2393] = -1.0*p[11];
out[2397] = -1.0*p[12];
out[2450] = p[16];
out[2498] = -p[15];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[51] = 184.75059629806526;
out[52] = 94.615102344455664;
out[53] = -69.368640085185305;
out[54] = -17.974903844364835;
out[55] = -43.675799641021079;
out[56] = -40.748687841669557;
out[57] = -69.368640085185291;
out[58] = -17.974903844364821;
out[59] = -184.75059629806526;
out[60] = -94.615102344455664;
out[61] = 69.368640085185305;
out[62] = 17.974903844364835;
out[63] = 43.675799641021079;
out[64] = 40.748687841669557;
out[65] = 69.368640085185291;
out[66] = 17.974903844364821;
out[67] = -1.0;
out[101] = -94.615102344455664;
out[102] = 184.75059629806526;
out[103] = 17.974903844364835;
out[104] = -69.368640085185305;
out[105] = 40.748687841669557;
out[106] = -43.675799641021079;
out[107] = 17.974903844364821;
out[108] = -69.368640085185291;
out[109] = 94.615102344455664;
out[110] = -184.75059629806526;
out[111] = -17.974903844364835;
out[112] = 69.368640085185305;
out[113] = -40.748687841669557;
out[114] = 43.675799641021079;
out[115] = -17.974903844364821;
out[116] = 69.368640085185291;
out[122] = -1.0;
out[151] = -69.368640085185291;
out[152] = -17.974903844364825;
out[153] = 184.7505962980652;
out[154] = 94.615102344455636;
out[155] = -69.368640085185319;
out[156] = -17.97490384436481;
out[157] = -43.675799641021079;
out[158] = -40.748687841669565;
out[159] = 69.368640085185291;
out[160] = 17.974903844364825;
out[161] = -184.7505962980652;
out[162] = -94.615102344455636;
out[163] = 69.368640085185319;
out[164] = 17.97490384436481;
out[165] = 43.675799641021079;
out[166] = 40.748687841669565;
out[168] = -1.0;
out[201] = 17.974903844364825;
out[202] = -69.368640085185291;
out[203] = -94.615102344455636;
out[204] = 184.7505962980652;
out[205] = 17.97490384436481;
out[206] = -69.368640085185319;
out[207] = 40.748687841669565;
out[208] = -43.675799641021079;
out[209] = -17.974903844364825;
out[210] = 69.368640085185291;
out[211] = 94.615102344455636;
out[212] = -184.7505962980652;
out[213] = -17.97490384436481;
out[214] = 69.368640085185319;
out[215] = -40.748687841669565;
out[216] = 43.675799641021079;
out[223] = -1.0;
out[251] = -43.675799641021101;
out[252] = -40.748687841669579;
out[253] = -69.368640085185305;
out[254] = -17.974903844364821;
out[255] = 184.75059629806526;
out[256] = 94.61510234445565;
out[257] = -69.368640085185305;
out[258] = -17.974903844364821;
out[259] = 43.675799641021101;
out[260] = 40.748687841669579;
out[261] = 69.368640085185305;
out[262] = 17.974903844364821;
out[263] = -184.75059629806526;
out[264] = -94.61510234445565;
out[265] = 69.368640085185305;
out[266] = 17.974903844364821;
out[269] = -1.0;
out[301] = 40.748687841669579;
out[302] = -43.675799641021101;
out[303] = 17.974903844364821;
out[304] = -69.368640085185305;
out[305] = -94.61510234445565;
out[306] = 184.75059629806526;
out[307] = 17.974903844364821;
out[308] = -69.368640085185305;
out[309] = -40.748687841669579;
out[310] = 43.675799641021101;
out[311] = -17.974903844364821;
out[312] = 69.368640085185305;
out[313] = 94.61510234445565;
out[314] = -184.75059629806526;
out[315] = -17.974903844364821;
out[316] = 69.368640085185305;
out[324] = -1.0;
out[351] = -69.368640085185305;
out[352] = -17.974903844364825;
out[353] = -43.675799641021079;
out[354] = -40.74868784166955;
out[355] = -69.368640085185291;
out[356] = -17.974903844364839;
out[357] = 184.7505962980652;
out[358] = 94.61510234445565;
out[359] = 69.368640085185305;
out[360] = 17.974903844364825;
out[361] = 43.675799641021079;
out[362] = 40.74868784166955;
out[363] = 69.368640085185291;
out[364] = 17.974903844364839;
out[365] = -184.7505962980652;
out[366] = -94.61510234445565;
out[370] = -1.0;
out[401] = 17.974903844364825;
out[402] = -69.368640085185305;
out[403] = 40.74868784166955;
out[404] = -43.675799641021079;
out[405] = 17.974903844364839;
out[406] = -69.368640085185291;
out[407] = -94.61510234445565;
out[408] = 184.7505962980652;
out[409] = -17.974903844364825;
out[410] = 69.368640085185305;
out[411] = -40.74868784166955;
out[412] = 43.675799641021079;
out[413] = -17.974903844364839;
out[414] = 69.368640085185291;
out[415] = 94.61510234445565;
out[416] = -184.7505962980652;
out[425] = -1.0;
out[451] = -184.75059629806526;
out[452] = -94.615102344455664;
out[453] = 69.368640085185305;
out[454] = 17.974903844364835;
out[455] = 43.675799641021079;
out[456] = 40.748687841669557;
out[457] = 69.368640085185291;
out[458] = 17.974903844364821;
out[459] = 184.75059629806526;
out[460] = 94.615102344455664;
out[461] = -69.368640085185305;
out[462] = -17.974903844364835;
out[463] = -43.675799641021079;
out[464] = -40.748687841669557;
out[465] = -69.368640085185291;
out[466] = -17.974903844364821;
out[490] = -1.0;
out[501] = 94.615102344455664;
out[502] = -184.75059629806526;
out[503] = -17.974903844364835;
out[504] = 69.368640085185305;
out[505] = -40.748687841669557;
out[506] = 43.675799641021079;
out[507] = -17.974903844364821;
out[508] = 69.368640085185291;
out[509] = -94.615102344455664;
out[510] = 184.75059629806526;
out[511] = 17.974903844364835;
out[512] = -69.368640085185305;
out[513] = 40.748687841669557;
out[514] = -43.675799641021079;
out[515] = 17.974903844364821;
out[516] = -69.368640085185291;
out[544] = -1.0;
out[551] = 69.368640085185291;
out[552] = 17.974903844364825;
out[553] = -184.7505962980652;
out[554] = -94.615102344455636;
out[555] = 69.368640085185319;
out[556] = 17.97490384436481;
out[557] = 43.675799641021079;
out[558] = 40.748687841669565;
out[559] = -69.368640085185291;
out[560] = -17.974903844364825;
out[561] = 184.7505962980652;
out[562] = 94.615102344455636;
out[563] = -69.368640085185319;
out[564] = -17.97490384436481;
out[565] = -43.675799641021079;
out[566] = -40.748687841669565;
out[591] = -1.0;
out[601] = -17.974903844364825;
out[602] = 69.368640085185291;
out[603] = 94.615102344455636;
out[604] = -184.7505962980652;
out[605] = -17.97490384436481;
out[606] = 69.368640085185319;
out[607] = -40.748687841669565;
out[608] = 43.675799641021079;
out[609] = 17.974903844364825;
out[610] = -69.368640085185291;
out[611] = -94.615102344455636;
out[612] = 184.7505962980652;
out[613] = 17.97490384436481;
out[614] = -69.368640085185319;
out[615] = 40.748687841669565;
out[616] = -43.675799641021079;
out[645] = -1.0;
out[651] = 43.675799641021101;
out[652] = 40.748687841669579;
out[653] = 69.368640085185305;
out[654] = 17.974903844364821;
out[655] = -184.75059629806526;
out[656] = -94.61510234445565;
out[657] = 69.368640085185305;
out[658] = 17.974903844364821;
out[659] = -43.675799641021101;
out[660] = -40.748687841669579;
out[661] = -69.368640085185305;
out[662] = -17.974903844364821;
out[663] = 184.75059629806526;
out[664] = 94.61510234445565;
out[665] = -69.368640085185305;
out[666] = -17.974903844364821;
out[692] = -1.0;
out[701] = -40.748687841669579;
out[702] = 43.675799641021101;
out[703] = -17.974903844364821;
out[704] = 69.368640085185305;
out[705] = 94.61510234445565;
out[706] = -184.75059629806526;
out[707] = -17.974903844364821;
out[708] = 69.368640085185305;
out[709] = 40.748687841669579;
out[710] = -43.675799641021101;
out[711] = 17.974903844364821;
out[712] = -69.368640085185305;
out[713] = -94.61510234445565;
out[714] = 184.75059629806526;
out[715] = 17.974903844364821;
out[716] = -69.368640085185305;
out[746] = -1.0;
out[751] = 69.368640085185305;
out[752] = 17.974903844364825;
out[753] = 43.675799641021079;
out[754] = 40.74868784166955;
out[755] = 69.368640085185291;
out[756] = 17.974903844364839;
out[757] = -184.7505962980652;
out[758] = -94.61510234445565;
out[759] = -69.368640085185305;
out[760] = -17.974903844364825;
out[761] = -43.675799641021079;
out[762] = -40.74868784166955;
out[763] = -69.368640085185291;
out[764] = -17.974903844364839;
out[765] = 184.7505962980652;
out[766] = 94.61510234445565;
out[793] = -1.0;
out[801] = -17.974903844364825;
out[802] = 69.368640085185305;
out[803] = -40.74868784166955;
out[804] = 43.675799641021079;
out[805] = -17.974903844364839;
out[806] = 69.368640085185291;
out[807] = 94.61510234445565;
out[808] = -184.7505962980652;
out[809] = 17.974903844364825;
out[810] = -69.368640085185305;
out[811] = 40.74868784166955;
out[812] = -43.675799641021079;
out[813] = 17.974903844364839;
out[814] = -69.368640085185291;
out[815] = -94.61510234445565;
out[816] = 184.7505962980652;
out[847] = -1.0;
out[851] = -1.0;
out[871] = 1.0;
out[884] = 1.0;
out[903] = -1.0;
out[921] = 1.0;
out[935] = 1.0;
out[955] = -1.0;
out[971] = 1.0;
out[986] = 1.0;
out[1007] = -1.0;
out[1021] = 1.0;
out[1067] = 1.0;
out[1068] = 1.0;
out[1069] = 1.0;
out[1070] = 1.0;
out[1102] = -1.0;
out[1126] = 1.0;
out[1137] = 1.0;
out[1154] = -1.0;
out[1176] = 1.0;
out[1188] = 1.0;
out[1206] = -1.0;
out[1226] = 1.0;
out[1239] = 1.0;
out[1258] = -1.0;
out[1276] = 1.0;
out[1322] = 1.0;
out[1323] = 1.0;
out[1324] = 1.0;
out[1325] = 1.0;
out[1377] = -1.0;
out[1701] = -1.0;
out[1734] = 1.0;
out[1753] = -1.0;
out[1785] = 1.0;
out[1805] = -1.0;
out[1836] = 1.0;
out[1852] = -1.0;
out[1887] = 1.0;
out[1904] = -1.0;
out[1938] = 1.0;
out[1956] = -1.0;
out[1989] = 1.0;
out[2009] = -1.0;
out[2061] = -1.0;
out[2113] = -1.0;
out[2165] = -1.0;
out[2210] = -1.0;
out[2262] = -1.0;
out[2314] = -1.0;
out[2366] = -1.0;
out[2448] = -1.0;
out[2499] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[324] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[33];
out[325] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[34];
out[326] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[35] + u[0];
out[327] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[328] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[36];
out[329] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[37];
out[330] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38] + 1.0*u[1];
out[331] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[333] = y[16];
out[334] = y[17];
out[335] = y[18];
out[336] = 1.0*y[21];
out[337] = 1.0*y[22];
out[338] = 1.0*y[23];
out[339] = -y[27];
out[340] = -1.0*y[30];
out[341] = -y[0];
out[342] = -1.0*y[1];
out[343] = -y[28];
out[344] = -1.0*y[31];
out[345] = -y[2];
out[346] = -1.0*y[3];
out[347] = -y[29];
out[348] = -1.0*y[32];
out[349] = -y[4];
out[350] = -1.0*y[5];
out[351] = 1.0*y[30];
out[352] = -1.0*y[27];
out[353] = -1.0*y[1];
out[354] = 1.0*y[0];
out[355] = 1.0*y[31];
out[356] = -1.0*y[28];
out[357] = -1.0*y[3];
out[358] = 1.0*y[2];
out[359] = 1.0*y[32];
out[360] = -1.0*y[29];
out[361] = -1.0*y[5];
out[362] = 1.0*y[4];

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[17] + 1.0;
out[1] = 0.5*Dt;
out[275] = -p[1];
out[277] = 1.0*p[0];
out[280] = -p[1];
out[282] = 1.0*p[0];
out[285] = -p[1];
out[287] = 1.0*p[0];
out[290] = -p[3];
out[292] = 1.0*p[2];
out[297] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[298] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[300] = -1.0*p[0];
out[301] = -1.0*p[1];
out[305] = -1.0*p[0];
out[306] = -1.0*p[1];
out[310] = -1.0*p[0];
out[311] = -1.0*p[1];
out[315] = -1.0*p[2];
out[316] = -1.0*p[3];
out[318] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[323] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[364] = -p[1];
out[365] = 1.0*p[0];
out[368] = -p[1];
out[369] = 1.0*p[0];
out[372] = -p[1];
out[373] = 1.0*p[0];
out[376] = -p[0];
out[377] = -1.0*p[1];
out[380] = -p[0];
out[381] = -1.0*p[1];
out[384] = -p[0];
out[385] = -1.0*p[1];
out[388] = -p[10];
out[389] = 1.0*p[9];
out[391] = -p[10];
out[392] = 1.0*p[9];
out[394] = -p[10];
out[395] = 1.0*p[9];
out[397] = -p[12];
out[398] = 1.0*p[11];
out[400] = -1.0*p[9];
out[401] = -1.0*p[10];
out[403] = -1.0*p[9];
out[404] = -1.0*p[10];
out[406] = -1.0*p[9];
out[407] = -1.0*p[10];
out[409] = -1.0*p[11];
out[410] = -1.0*p[12];
out[412] = p[16];
out[413] = -p[15];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = 184.75059629806526;
out[3] = 94.615102344455664;
out[4] = -69.368640085185305;
out[5] = -17.974903844364835;
out[6] = -43.675799641021079;
out[7] = -40.748687841669557;
out[8] = -69.368640085185291;
out[9] = -17.974903844364821;
out[10] = -184.75059629806526;
out[11] = -94.615102344455664;
out[12] = 69.368640085185305;
out[13] = 17.974903844364835;
out[14] = 43.675799641021079;
out[15] = 40.748687841669557;
out[16] = 69.368640085185291;
out[17] = 17.974903844364821;
out[18] = -1.0;
out[19] = -94.615102344455664;
out[20] = 184.75059629806526;
out[21] = 17.974903844364835;
out[22] = -69.368640085185305;
out[23] = 40.748687841669557;
out[24] = -43.675799641021079;
out[25] = 17.974903844364821;
out[26] = -69.368640085185291;
out[27] = 94.615102344455664;
out[28] = -184.75059629806526;
out[29] = -17.974903844364835;
out[30] = 69.368640085185305;
out[31] = -40.748687841669557;
out[32] = 43.675799641021079;
out[33] = -17.974903844364821;
out[34] = 69.368640085185291;
out[35] = -1.0;
out[36] = -69.368640085185291;
out[37] = -17.974903844364825;
out[38] = 184.7505962980652;
out[39] = 94.615102344455636;
out[40] = -69.368640085185319;
out[41] = -17.97490384436481;
out[42] = -43.675799641021079;
out[43] = -40.748687841669565;
out[44] = 69.368640085185291;
out[45] = 17.974903844364825;
out[46] = -184.7505962980652;
out[47] = -94.615102344455636;
out[48] = 69.368640085185319;
out[49] = 17.97490384436481;
out[50] = 43.675799641021079;
out[51] = 40.748687841669565;
out[52] = -1.0;
out[53] = 17.974903844364825;
out[54] = -69.368640085185291;
out[55] = -94.615102344455636;
out[56] = 184.7505962980652;
out[57] = 17.97490384436481;
out[58] = -69.368640085185319;
out[59] = 40.748687841669565;
out[60] = -43.675799641021079;
out[61] = -17.974903844364825;
out[62] = 69.368640085185291;
out[63] = 94.615102344455636;
out[64] = -184.7505962980652;
out[65] = -17.97490384436481;
out[66] = 69.368640085185319;
out[67] = -40.748687841669565;
out[68] = 43.675799641021079;
out[69] = -1.0;
out[70] = -43.675799641021101;
out[71] = -40.748687841669579;
out[72] = -69.368640085185305;
out[73] = -17.974903844364821;
out[74] = 184.75059629806526;
out[75] = 94.61510234445565;
out[76] = -69.368640085185305;
out[77] = -17.974903844364821;
out[78] = 43.675799641021101;
out[79] = 40.748687841669579;
out[80] = 69.368640085185305;
out[81] = 17.974903844364821;
out[82] = -184.75059629806526;
out[83] = -94.61510234445565;
out[84] = 69.368640085185305;
out[85] = 17.974903844364821;
out[86] = -1.0;
out[87] = 40.748687841669579;
out[88] = -43.675799641021101;
out[89] = 17.974903844364821;
out[90] = -69.368640085185305;
out[91] = -94.61510234445565;
out[92] = 184.75059629806526;
out[93] = 17.974903844364821;
out[94] = -69.368640085185305;
out[95] = -40.748687841669579;
out[96] = 43.675799641021101;
out[97] = -17.974903844364821;
out[98] = 69.368640085185305;
out[99] = 94.61510234445565;
out[100] = -184.75059629806526;
out[101] = -17.974903844364821;
out[102] = 69.368640085185305;
out[103] = -1.0;
out[104] = -69.368640085185305;
out[105] = -17.974903844364825;
out[106] = -43.675799641021079;
out[107] = -40.74868784166955;
out[108] = -69.368640085185291;
out[109] = -17.974903844364839;
out[110] = 184.7505962980652;
out[111] = 94.61510234445565;
out[112] = 69.368640085185305;
out[113] = 17.974903844364825;
out[114] = 43.675799641021079;
out[115] = 40.74868784166955;
out[116] = 69.368640085185291;
out[117] = 17.974903844364839;
out[118] = -184.7505962980652;
out[119] = -94.61510234445565;
out[120] = -1.0;
out[121] = 17.974903844364825;
out[122] = -69.368640085185305;
out[123] = 40.74868784166955;
out[124] = -43.675799641021079;
out[125] = 17.974903844364839;
out[126] = -69.368640085185291;
out[127] = -94.61510234445565;
out[128] = 184.7505962980652;
out[129] = -17.974903844364825;
out[130] = 69.368640085185305;
out[131] = -40.74868784166955;
out[132] = 43.675799641021079;
out[133] = -17.974903844364839;
out[134] = 69.368640085185291;
out[135] = 94.61510234445565;
out[136] = -184.7505962980652;
out[137] = -1.0;
out[138] = -184.75059629806526;
out[139] = -94.615102344455664;
out[140] = 69.368640085185305;
out[141] = 17.974903844364835;
out[142] = 43.675799641021079;
out[143] = 40.748687841669557;
out[144] = 69.368640085185291;
out[145] = 17.974903844364821;
out[146] = 184.75059629806526;
out[147] = 94.615102344455664;
out[148] = -69.368640085185305;
out[149] = -17.974903844364835;
out[150] = -43.675799641021079;
out[151] = -40.748687841669557;
out[152] = -69.368640085185291;
out[153] = -17.974903844364821;
out[154] = -1.0;
out[155] = 94.615102344455664;
out[156] = -184.75059629806526;
out[157] = -17.974903844364835;
out[158] = 69.368640085185305;
out[159] = -40.748687841669557;
out[160] = 43.675799641021079;
out[161] = -17.974903844364821;
out[162] = 69.368640085185291;
out[163] = -94.615102344455664;
out[164] = 184.75059629806526;
out[165] = 17.974903844364835;
out[166] = -69.368640085185305;
out[167] = 40.748687841669557;
out[168] = -43.675799641021079;
out[169] = 17.974903844364821;
out[170] = -69.368640085185291;
out[171] = -1.0;
out[172] = 69.368640085185291;
out[173] = 17.974903844364825;
out[174] = -184.7505962980652;
out[175] = -94.615102344455636;
out[176] = 69.368640085185319;
out[177] = 17.97490384436481;
out[178] = 43.675799641021079;
out[179] = 40.748687841669565;
out[180] = -69.368640085185291;
out[181] = -17.974903844364825;
out[182] = 184.7505962980652;
out[183] = 94.615102344455636;
out[184] = -69.368640085185319;
out[185] = -17.97490384436481;
out[186] = -43.675799641021079;
out[187] = -40.748687841669565;
out[188] = -1.0;
out[189] = -17.974903844364825;
out[190] = 69.368640085185291;
out[191] = 94.615102344455636;
out[192] = -184.7505962980652;
out[193] = -17.97490384436481;
out[194] = 69.368640085185319;
out[195] = -40.748687841669565;
out[196] = 43.675799641021079;
out[197] = 17.974903844364825;
out[198] = -69.368640085185291;
out[199] = -94.615102344455636;
out[200] = 184.7505962980652;
out[201] = 17.97490384436481;
out[202] = -69.368640085185319;
out[203] = 40.748687841669565;
out[204] = -43.675799641021079;
out[205] = -1.0;
out[206] = 43.675799641021101;
out[207] = 40.748687841669579;
out[208] = 69.368640085185305;
out[209] = 17.974903844364821;
out[210] = -184.75059629806526;
out[211] = -94.61510234445565;
out[212] = 69.368640085185305;
out[213] = 17.974903844364821;
out[214] = -43.675799641021101;
out[215] = -40.748687841669579;
out[216] = -69.368640085185305;
out[217] = -17.974903844364821;
out[218] = 184.75059629806526;
out[219] = 94.61510234445565;
out[220] = -69.368640085185305;
out[221] = -17.974903844364821;
out[222] = -1.0;
out[223] = -40.748687841669579;
out[224] = 43.675799641021101;
out[225] = -17.974903844364821;
out[226] = 69.368640085185305;
out[227] = 94.61510234445565;
out[228] = -184.75059629806526;
out[229] = -17.974903844364821;
out[230] = 69.368640085185305;
out[231] = 40.748687841669579;
out[232] = -43.675799641021101;
out[233] = 17.974903844364821;
out[234] = -69.368640085185305;
out[235] = -94.61510234445565;
out[236] = 184.75059629806526;
out[237] = 17.974903844364821;
out[238] = -69.368640085185305;
out[239] = -1.0;
out[240] = 69.368640085185305;
out[241] = 17.974903844364825;
out[242] = 43.675799641021079;
out[243] = 40.74868784166955;
out[244] = 69.368640085185291;
out[245] = 17.974903844364839;
out[246] = -184.7505962980652;
out[247] = -94.61510234445565;
out[248] = -69.368640085185305;
out[249] = -17.974903844364825;
out[250] = -43.675799641021079;
out[251] = -40.74868784166955;
out[252] = -69.368640085185291;
out[253] = -17.974903844364839;
out[254] = 184.7505962980652;
out[255] = 94.61510234445565;
out[256] = -1.0;
out[257] = -17.974903844364825;
out[258] = 69.368640085185305;
out[259] = -40.74868784166955;
out[260] = 43.675799641021079;
out[261] = -17.974903844364839;
out[262] = 69.368640085185291;
out[263] = 94.61510234445565;
out[264] = -184.7505962980652;
out[265] = 17.974903844364825;
out[266] = -69.368640085185305;
out[267] = 40.74868784166955;
out[268] = -43.675799641021079;
out[269] = 17.974903844364839;
out[270] = -69.368640085185291;
out[271] = -94.61510234445565;
out[272] = 184.7505962980652;
out[273] = -1.0;
out[274] = -1.0;
out[276] = 1.0;
out[278] = 1.0;
out[279] = -1.0;
out[281] = 1.0;
out[283] = 1.0;
out[284] = -1.0;
out[286] = 1.0;
out[288] = 1.0;
out[289] = -1.0;
out[291] = 1.0;
out[293] = 1.0;
out[294] = 1.0;
out[295] = 1.0;
out[296] = 1.0;
out[299] = -1.0;
out[302] = 1.0;
out[303] = 1.0;
out[304] = -1.0;
out[307] = 1.0;
out[308] = 1.0;
out[309] = -1.0;
out[312] = 1.0;
out[313] = 1.0;
out[314] = -1.0;
out[317] = 1.0;
out[319] = 1.0;
out[320] = 1.0;
out[321] = 1.0;
out[322] = 1.0;
out[332] = -1.0;
out[363] = -1.0;
out[366] = 1.0;
out[367] = -1.0;
out[370] = 1.0;
out[371] = -1.0;
out[374] = 1.0;
out[375] = -1.0;
out[378] = 1.0;
out[379] = -1.0;
out[382] = 1.0;
out[383] = -1.0;
out[386] = 1.0;
out[387] = -1.0;
out[390] = -1.0;
out[393] = -1.0;
out[396] = -1.0;
out[399] = -1.0;
out[402] = -1.0;
out[405] = -1.0;
out[408] = -1.0;
out[411] = -1.0;
out[414] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[15] = 1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[416] = y[18];
out[417] = 1.0*y[23];

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[634] = cos(u[14]);
out[638] = -u[10]*sin(u[14]);
out[651] = cos(u[14] - 2.0943951023931953);
out[654] = -u[11]*sin(u[14] - 2.0943951023931953);
out[668] = cos(u[14] - 4.1887902047863905);
out[670] = -u[12]*sin(u[14] - 4.1887902047863905);
out[698] = 1.0*sin(u[14]);
out[702] = 1.0*u[10]*cos(u[14]);
out[715] = 1.0*sin(u[14] - 2.0943951023931953);
out[718] = 1.0*u[11]*cos(u[14] - 2.0943951023931953);
out[732] = 1.0*sin(u[14] - 4.1887902047863905);
out[734] = 1.0*u[12]*cos(u[14] - 4.1887902047863905);

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[304] = 1.0;
out[385] = 1.0;
out[434] = 1.0;
out[437] = 0.33333333333333331;
out[451] = 1.0;
out[453] = 0.33333333333333331;
out[468] = 1.0;
out[469] = 0.33333333333333331;
out[486] = 1.0;
out[489] = 0.33333333333333331;
out[503] = 1.0;
out[505] = 0.33333333333333331;
out[520] = 1.0;
out[521] = 0.33333333333333331;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[25] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[408] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[413] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[458] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[463] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[508] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[513] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[558] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[563] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[588] = y[16];
out[589] = 1.0*y[21];
out[604] = y[0];
out[609] = 1.0*y[1];
out[637] = -1.0*y[21];
out[638] = 1.0*y[16];
out[653] = 1.0*y[1];
out[658] = -1.0*y[0];
out[688] = y[17];
out[689] = 1.0*y[22];
out[703] = y[2];
out[708] = 1.0*y[3];
out[737] = -1.0*y[22];
out[738] = 1.0*y[17];
out[752] = 1.0*y[3];
out[757] = -1.0*y[2];
out[788] = y[18];
out[789] = 1.0*y[23];
out[802] = y[4];
out[807] = 1.0*y[5];
out[837] = -1.0*y[23];
out[838] = 1.0*y[18];
out[851] = 1.0*y[5];
out[856] = -1.0*y[4];
out[970] = y[39]*pow(1.0*pow(y[43], 2) + pow(y[39], 2), -0.5);
out[974] = 1.0*y[43]*pow(1.0*pow(y[43], 2) + pow(y[39], 2), -0.5);
out[1020] = y[40]*pow(1.0*pow(y[44], 2) + pow(y[40], 2), -0.5);
out[1024] = 1.0*y[44]*pow(1.0*pow(y[44], 2) + pow(y[40], 2), -0.5);
out[1070] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1074] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1120] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1124] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1135] = y[39];
out[1136] = 1.0*y[43];
out[1137] = y[40];
out[1138] = 1.0*y[44];
out[1139] = y[41];
out[1140] = 1.0*y[45];
out[1166] = y[8];
out[1167] = y[10];
out[1168] = y[12];
out[1170] = 1.0*y[9];
out[1171] = 1.0*y[11];
out[1172] = 1.0*y[13];
out[1184] = -1.0*y[43];
out[1185] = 1.0*y[39];
out[1186] = -1.0*y[44];
out[1187] = 1.0*y[40];
out[1188] = -1.0*y[45];
out[1189] = 1.0*y[41];
out[1215] = 1.0*y[9];
out[1216] = 1.0*y[11];
out[1217] = 1.0*y[13];
out[1219] = -1.0*y[8];
out[1220] = -1.0*y[10];
out[1221] = -1.0*y[12];

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[49] = -94.615102344455664;
out[50] = 184.75059629806526;
out[51] = 17.974903844364835;
out[52] = -69.368640085185305;
out[53] = 40.748687841669557;
out[54] = -43.675799641021079;
out[55] = 17.974903844364821;
out[56] = -69.368640085185291;
out[57] = 94.615102344455664;
out[58] = -184.75059629806526;
out[59] = -17.974903844364835;
out[60] = 69.368640085185305;
out[61] = -40.748687841669557;
out[62] = 43.675799641021079;
out[63] = -17.974903844364821;
out[64] = 69.368640085185291;
out[98] = -69.368640085185291;
out[99] = -17.974903844364825;
out[100] = 184.7505962980652;
out[101] = 94.615102344455636;
out[102] = -69.368640085185319;
out[103] = -17.97490384436481;
out[104] = -43.675799641021079;
out[105] = -40.748687841669565;
out[106] = 69.368640085185291;
out[107] = 17.974903844364825;
out[108] = -184.7505962980652;
out[109] = -94.615102344455636;
out[110] = 69.368640085185319;
out[111] = 17.97490384436481;
out[112] = 43.675799641021079;
out[113] = 40.748687841669565;
out[147] = 17.974903844364825;
out[148] = -69.368640085185291;
out[149] = -94.615102344455636;
out[150] = 184.7505962980652;
out[151] = 17.97490384436481;
out[152] = -69.368640085185319;
out[153] = 40.748687841669565;
out[154] = -43.675799641021079;
out[155] = -17.974903844364825;
out[156] = 69.368640085185291;
out[157] = 94.615102344455636;
out[158] = -184.7505962980652;
out[159] = -17.97490384436481;
out[160] = 69.368640085185319;
out[161] = -40.748687841669565;
out[162] = 43.675799641021079;
out[196] = -43.675799641021101;
out[197] = -40.748687841669579;
out[198] = -69.368640085185305;
out[199] = -17.974903844364821;
out[200] = 184.75059629806526;
out[201] = 94.61510234445565;
out[202] = -69.368640085185305;
out[203] = -17.974903844364821;
out[204] = 43.675799641021101;
out[205] = 40.748687841669579;
out[206] = 69.368640085185305;
out[207] = 17.974903844364821;
out[208] = -184.75059629806526;
out[209] = -94.61510234445565;
out[210] = 69.368640085185305;
out[211] = 17.974903844364821;
out[245] = 40.748687841669579;
out[246] = -43.675799641021101;
out[247] = 17.974903844364821;
out[248] = -69.368640085185305;
out[249] = -94.61510234445565;
out[250] = 184.75059629806526;
out[251] = 17.974903844364821;
out[252] = -69.368640085185305;
out[253] = -40.748687841669579;
out[254] = 43.675799641021101;
out[255] = -17.974903844364821;
out[256] = 69.368640085185305;
out[257] = 94.61510234445565;
out[258] = -184.75059629806526;
out[259] = -17.974903844364821;
out[260] = 69.368640085185305;
out[294] = -69.368640085185305;
out[295] = -17.974903844364825;
out[296] = -43.675799641021079;
out[297] = -40.74868784166955;
out[298] = -69.368640085185291;
out[299] = -17.974903844364839;
out[300] = 184.7505962980652;
out[301] = 94.61510234445565;
out[302] = 69.368640085185305;
out[303] = 17.974903844364825;
out[304] = 43.675799641021079;
out[305] = 40.74868784166955;
out[306] = 69.368640085185291;
out[307] = 17.974903844364839;
out[308] = -184.7505962980652;
out[309] = -94.61510234445565;
out[343] = 17.974903844364825;
out[344] = -69.368640085185305;
out[345] = 40.74868784166955;
out[346] = -43.675799641021079;
out[347] = 17.974903844364839;
out[348] = -69.368640085185291;
out[349] = -94.61510234445565;
out[350] = 184.7505962980652;
out[351] = -17.974903844364825;
out[352] = 69.368640085185305;
out[353] = -40.74868784166955;
out[354] = 43.675799641021079;
out[355] = -17.974903844364839;
out[356] = 69.368640085185291;
out[357] = 94.61510234445565;
out[358] = -184.7505962980652;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[293] = 1.0;
out[431] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = y[18];
out[3] = 1.0*y[23];

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[16] = cos(u[14]);
out[17] = -u[10]*sin(u[14]);
out[18] = cos(u[14] - 2.0943951023931953);
out[19] = -u[11]*sin(u[14] - 2.0943951023931953);
out[20] = cos(u[14] - 4.1887902047863905);
out[21] = -u[12]*sin(u[14] - 4.1887902047863905);
out[22] = 1.0*sin(u[14]);
out[23] = 1.0*u[10]*cos(u[14]);
out[24] = 1.0*sin(u[14] - 2.0943951023931953);
out[25] = 1.0*u[11]*cos(u[14] - 2.0943951023931953);
out[26] = 1.0*sin(u[14] - 4.1887902047863905);
out[27] = 1.0*u[12]*cos(u[14] - 4.1887902047863905);

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[4] = 1.0;
out[5] = 0.33333333333333331;
out[6] = 1.0;
out[7] = 0.33333333333333331;
out[8] = 1.0;
out[9] = 0.33333333333333331;
out[10] = 1.0;
out[11] = 0.33333333333333331;
out[12] = 1.0;
out[13] = 0.33333333333333331;
out[14] = 1.0;
out[15] = 0.33333333333333331;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[128] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[129] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[130] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[131] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[132] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[133] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[134] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[135] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[136] = y[16];
out[137] = 1.0*y[21];
out[138] = y[0];
out[139] = 1.0*y[1];
out[140] = -1.0*y[21];
out[141] = 1.0*y[16];
out[142] = 1.0*y[1];
out[143] = -1.0*y[0];
out[144] = y[17];
out[145] = 1.0*y[22];
out[146] = y[2];
out[147] = 1.0*y[3];
out[148] = -1.0*y[22];
out[149] = 1.0*y[17];
out[150] = 1.0*y[3];
out[151] = -1.0*y[2];
out[152] = y[18];
out[153] = 1.0*y[23];
out[154] = y[4];
out[155] = 1.0*y[5];
out[156] = -1.0*y[23];
out[157] = 1.0*y[18];
out[158] = 1.0*y[5];
out[159] = -1.0*y[4];
out[160] = y[39]*pow(1.0*pow(y[43], 2) + pow(y[39], 2), -0.5);
out[161] = 1.0*y[43]*pow(1.0*pow(y[43], 2) + pow(y[39], 2), -0.5);
out[162] = y[40]*pow(1.0*pow(y[44], 2) + pow(y[40], 2), -0.5);
out[163] = 1.0*y[44]*pow(1.0*pow(y[44], 2) + pow(y[40], 2), -0.5);
out[164] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[165] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[166] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[167] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[168] = y[39];
out[169] = 1.0*y[43];
out[170] = y[40];
out[171] = 1.0*y[44];
out[172] = y[41];
out[173] = 1.0*y[45];
out[174] = y[8];
out[175] = y[10];
out[176] = y[12];
out[177] = 1.0*y[9];
out[178] = 1.0*y[11];
out[179] = 1.0*y[13];
out[180] = -1.0*y[43];
out[181] = 1.0*y[39];
out[182] = -1.0*y[44];
out[183] = 1.0*y[40];
out[184] = -1.0*y[45];
out[185] = 1.0*y[41];
out[186] = 1.0*y[9];
out[187] = 1.0*y[11];
out[188] = 1.0*y[13];
out[189] = -1.0*y[8];
out[190] = -1.0*y[10];
out[191] = -1.0*y[12];

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[16] = -94.615102344455664;
out[17] = 184.75059629806526;
out[18] = 17.974903844364835;
out[19] = -69.368640085185305;
out[20] = 40.748687841669557;
out[21] = -43.675799641021079;
out[22] = 17.974903844364821;
out[23] = -69.368640085185291;
out[24] = 94.615102344455664;
out[25] = -184.75059629806526;
out[26] = -17.974903844364835;
out[27] = 69.368640085185305;
out[28] = -40.748687841669557;
out[29] = 43.675799641021079;
out[30] = -17.974903844364821;
out[31] = 69.368640085185291;
out[32] = -69.368640085185291;
out[33] = -17.974903844364825;
out[34] = 184.7505962980652;
out[35] = 94.615102344455636;
out[36] = -69.368640085185319;
out[37] = -17.97490384436481;
out[38] = -43.675799641021079;
out[39] = -40.748687841669565;
out[40] = 69.368640085185291;
out[41] = 17.974903844364825;
out[42] = -184.7505962980652;
out[43] = -94.615102344455636;
out[44] = 69.368640085185319;
out[45] = 17.97490384436481;
out[46] = 43.675799641021079;
out[47] = 40.748687841669565;
out[48] = 17.974903844364825;
out[49] = -69.368640085185291;
out[50] = -94.615102344455636;
out[51] = 184.7505962980652;
out[52] = 17.97490384436481;
out[53] = -69.368640085185319;
out[54] = 40.748687841669565;
out[55] = -43.675799641021079;
out[56] = -17.974903844364825;
out[57] = 69.368640085185291;
out[58] = 94.615102344455636;
out[59] = -184.7505962980652;
out[60] = -17.97490384436481;
out[61] = 69.368640085185319;
out[62] = -40.748687841669565;
out[63] = 43.675799641021079;
out[64] = -43.675799641021101;
out[65] = -40.748687841669579;
out[66] = -69.368640085185305;
out[67] = -17.974903844364821;
out[68] = 184.75059629806526;
out[69] = 94.61510234445565;
out[70] = -69.368640085185305;
out[71] = -17.974903844364821;
out[72] = 43.675799641021101;
out[73] = 40.748687841669579;
out[74] = 69.368640085185305;
out[75] = 17.974903844364821;
out[76] = -184.75059629806526;
out[77] = -94.61510234445565;
out[78] = 69.368640085185305;
out[79] = 17.974903844364821;
out[80] = 40.748687841669579;
out[81] = -43.675799641021101;
out[82] = 17.974903844364821;
out[83] = -69.368640085185305;
out[84] = -94.61510234445565;
out[85] = 184.75059629806526;
out[86] = 17.974903844364821;
out[87] = -69.368640085185305;
out[88] = -40.748687841669579;
out[89] = 43.675799641021101;
out[90] = -17.974903844364821;
out[91] = 69.368640085185305;
out[92] = 94.61510234445565;
out[93] = -184.75059629806526;
out[94] = -17.974903844364821;
out[95] = 69.368640085185305;
out[96] = -69.368640085185305;
out[97] = -17.974903844364825;
out[98] = -43.675799641021079;
out[99] = -40.74868784166955;
out[100] = -69.368640085185291;
out[101] = -17.974903844364839;
out[102] = 184.7505962980652;
out[103] = 94.61510234445565;
out[104] = 69.368640085185305;
out[105] = 17.974903844364825;
out[106] = 43.675799641021079;
out[107] = 40.74868784166955;
out[108] = 69.368640085185291;
out[109] = 17.974903844364839;
out[110] = -184.7505962980652;
out[111] = -94.61510234445565;
out[112] = 17.974903844364825;
out[113] = -69.368640085185305;
out[114] = 40.74868784166955;
out[115] = -43.675799641021079;
out[116] = 17.974903844364839;
out[117] = -69.368640085185291;
out[118] = -94.61510234445565;
out[119] = 184.7505962980652;
out[120] = -17.974903844364825;
out[121] = 69.368640085185305;
out[122] = -40.74868784166955;
out[123] = 43.675799641021079;
out[124] = -17.974903844364839;
out[125] = 69.368640085185291;
out[126] = 94.61510234445565;
out[127] = -184.7505962980652;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_temp_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_temp_cffi(void) { return NULL; }
#  else
     inittemp_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_temp_cffi(void)
{
  return _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inittemp_cffi(void)
{
  _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
